import datetime

'''

    Source:
     https://bitbucket.org/mlissner/search-and-awareness-platform-courtlistener/src/tip/alert/citations/constants.py?at=default

    Notes:
     - Each Reporter key maps to a list of reporters that that key can represent. In some cases (especially in early
       reporters), the key is ambiguous, referring to more than one possible reporter.
     - Formats follow the Blue Book standard, with variations listed for local rules.
     - The 'variations' key consists of data from local rules, found through organic usage in our corpus and from the
       list at http://www.legalabbrevs.cardiff.ac.uk/. We have used a dict for these values due to the fact that there
       can be variations for each series.
     - mlz_jurisdiction corresponds to the work that is being done for reference software such as Zotero.
     - In reporters with multiple series, if multiple volumes have the same dates, this indicates that the point where
       one series ends and the other begins is unknown. These are good areas for research.

'''

REPORTERS = {'A.': [{'cite_type': 'state_regional',
                     'editions': {'A.': (datetime.date(1885, 1, 1),
                                         datetime.date(1938, 12, 31)),
                                  'A.2d': (datetime.date(1938, 1, 1),
                                           datetime.date(2010, 12, 31)),
                                  'A.3d': (datetime.date(2010, 1, 1),
                                           datetime.date.today())},
                     'mlz_jurisdiction': 'us',
                     'name': 'Atlantic Reporter',
                     'variations': {'A. 2d': 'A.2d',
                                    'A. 3d': 'A.3d',
                                    'A.R.': 'A.',
                                    'A.Rep.': 'A.',
                                    'At.': 'A.',
                                    'Atl.': 'A.',
                                    'Atl.2d': 'A.2d',
                                    'Atl.R.': 'A.'}}],
             'A.D.': [{'cite_type': 'state',
                       'editions': {'A.D.': (datetime.date(1896, 1, 1),
                                             datetime.date(1955, 12, 31)),
                                    'A.D.2d': (datetime.date(1955, 1, 1),
                                               datetime.date(2004, 12, 31)),
                                    'A.D.3d': (datetime.date(2003, 1, 1),
                                               datetime.date.today())},
                       'mlz_jurisdiction': 'us;ny',
                       'name': 'New York Supreme Court Appellate Division Reports',
                       'variations': {'A.D. 2d': 'A.D.2d',
                                      'A.D. 3d': 'A.D.3d',
                                      'AD 2d': 'A.D.2d',
                                      'AD 3d': 'A.D.3d',
                                      'Ap.': 'A.D.',
                                      'Ap.2d.': 'A.D.',
                                      'App.Div.': 'A.D.',
                                      'App.Div.(N.Y.)': 'A.D.',
                                      'App.Div.2d.': 'A.D.',
                                      'N.Y.App.Dec.': 'A.D.',
                                      'N.Y.App.Div.': 'A.D.'}}],
             'A.K. Marsh.': [{'cite_type': 'state',
                              'editions': {'A.K. Marsh.': (datetime.date(1817, 1, 1),
                                                           datetime.date(1821, 12, 31))},
                              'mlz_jurisdiction': 'us;ky',
                              'name': 'Kentucky Reports, Marshall, A.K.',
                              'variations': {'Ky.(A.K.Marsh.)': 'A.K. Marsh.',
                                             'Mar.': 'A.K. Marsh.',
                                             'Marsh.': 'A.K. Marsh.',
                                             'Marsh.(Ky.)': 'A.K. Marsh.',
                                             'Marsh.A.K.': 'A.K. Marsh.'}}],
             'AZ': [{'cite_type': 'neutral',
                     'editions': {'AZ': (datetime.date(1750, 1, 1),
                                         datetime.date.today())},
                     'mlz_jurisdiction': 'us;az',
                     'name': 'Arizona Neutral Citation',
                     'variations': {}}],
             'Abb. N. Cas.': [{'cite_type': 'state',
                               'editions': {'Abb. N. Cas.': (datetime.date(1876, 1, 1),
                                                             datetime.date(1894, 12, 31))},
                               'mlz_jurisdiction': 'us;ny',
                               'name': "Abbott's New Cases",
                               'variations': {'A.N.': 'Abb. N. Cas.',
                                              'A.N.C.': 'Abb. N. Cas.',
                                              'Abb.N.C.': 'Abb. N. Cas.'}}],
             'Abb. Pr.': [{'cite_type': 'state',
                           'editions': {'Abb. Pr.': (datetime.date(1854, 1, 1),
                                                     datetime.date(1875, 12, 31))},
                           'mlz_jurisdiction': 'us;ny',
                           'name': "Abbott's Practice Reports",
                           'variations': {'Abb.P.R.': 'Abb. Pr.',
                                          'Abb.Pr.Rep.': 'Abb. Pr.',
                                          'Abb.Prac.': 'Abb. Pr.',
                                          'Abbott P.R.': 'Abb. Pr.',
                                          'Abbott Pr.Rep.': 'Abb. Pr.',
                                          'Abbott Pract.Cas.': 'Abb. Pr.',
                                          "Abbott's Pr.Rep.": 'Abb. Pr.',
                                          "Abbott's Prac.Rep.": 'Abb. Pr.'}}],
             'Aik.': [{'cite_type': 'state',
                       'editions': {'Aik.': (datetime.date(1825, 1, 1),
                                             datetime.date(1828, 12, 31))},
                       'mlz_jurisdiction': 'us;vt',
                       'name': 'Vermont Reports, Aikens',
                       'variations': {}}],
             'Ala.': [{'cite_type': 'state',
                       'editions': {'Ala.': (datetime.date(1840, 1, 1),
                                             datetime.date(1976, 12, 31)),
                                    'Ala. 2d': (datetime.date(1977, 1, 1),
                                                datetime.date.today())},
                       'mlz_jurisdiction': 'us;al',
                       'name': 'Alabama Reports',
                       'variations': {}}],
             'Ala. App.': [{'cite_type': 'state',
                            'editions': {'Ala. App.': (datetime.date(1910, 1, 1),
                                                       datetime.date(1976, 12, 31))},
                            'mlz_jurisdiction': 'us;al',
                            'name': 'Alabama Appellate Courts Reports',
                            'variations': {}}],
             'Alaska': [{'cite_type': 'state',
                         'editions': {'Alaska': (datetime.date(1884, 1, 1),
                                                 datetime.date(1959, 12, 31))},
                         'mlz_jurisdiction': 'us;ak',
                         'name': 'Alaska Reports',
                         'variations': {'Alk.': 'Alaska'}}],
             'Alaska Fed.': [{'cite_type': 'state',
                              'editions': {'Alaska Fed.': (datetime.date(1869, 1, 1),
                                                           datetime.date(1937, 12, 31))},
                              'mlz_jurisdiction': 'us;ak',
                              'name': 'Alaska Federal Reports',
                              'variations': {'A.F.Rep.': 'Alaska Fed.',
                                             'Alaska Fed.': 'Alaska Fed.',
                                             'Alaska Fed.R.': 'Alaska Fed.',
                                             'Alaska Fed.Rep.': 'Alaska Fed.'}}],
             'Allen': [{'cite_type': 'state',
                        'editions': {'Allen': (datetime.date(1861, 1, 1),
                                               datetime.date(1867, 12, 31))},
                        'mlz_jurisdiction': 'us;ma',
                        'name': 'Massachusetts Reports, Allen',
                        'variations': {'All.': 'Allen', 'Mass.(Allen)': 'Allen'}}],
             'Am. Samoa': [{'cite_type': 'state',
                            'editions': {'Am. Samoa': (datetime.date(1900, 1, 1),
                                                       datetime.date.today()),
                                         'Am. Samoa 2d': (datetime.date(1900, 1, 1),
                                                          datetime.date.today())},
                            'mlz_jurisdiction': 'us;am',
                            'name': 'American Samoa Reports',
                            'variations': {}}],
             'Ant. N.P. Cas.': [{'cite_type': 'state',
                                 'editions': {'Ant. N.P. Cas.': (datetime.date(1807, 1, 1),
                                                                 datetime.date(1851, 12, 31))},
                                 'mlz_jurisdiction': 'us;ny',
                                 'name': "Anthon's Nisi Prius Cases",
                                 'variations': {'Anth.': 'Ant. N.P. Cas.',
                                                'Anthon N.P.(N.Y.)': 'Ant. N.P. Cas.'}}],
             'App. D.C.': [{'cite_type': 'state',
                            'editions': {'App. D.C.': (datetime.date(1893, 1, 1),
                                                       datetime.date(1941, 12, 31))},
                            'mlz_jurisdiction': 'us;dc',
                            'name': 'Appeal Cases, District of Colombia',
                            'variations': {}}],
             'Ariz.': [{'cite_type': 'state',
                        'editions': {'Ariz.': (datetime.date(1866, 1, 1),
                                               datetime.date.today())},
                        'mlz_jurisdiction': 'us;az',
                        'name': 'Arizona Reporter',
                        'variations': {}}],
             'Ariz. App.': [{'cite_type': 'state',
                             'editions': {'Ariz. App.': (datetime.date(1965, 1, 1),
                                                         datetime.date(1976, 12, 31))},
                             'mlz_jurisdiction': 'us;az',
                             'name': 'Arizona Appeals Reports',
                             'variations': {}}],
             'Ark.': [{'cite_type': 'state',
                       'editions': {'Ark.': (datetime.date(1837, 1, 1),
                                             datetime.date.today())},
                       'mlz_jurisdiction': 'us;ar',
                       'name': 'Arkansas Reports',
                       'variations': {'Ak.': 'Ark.'}}],
             'Ark. App.': [{'cite_type': 'state',
                            'editions': {'Ark. App.': (datetime.date(1981, 1, 1),
                                                       datetime.date.today())},
                            'mlz_jurisdiction': 'us;ar',
                            'name': 'Arkansas Appellate Reports',
                            'variations': {'Ak. App.': 'Ark. App.'}}],
             'B. Mon.': [{'cite_type': 'state',
                          'editions': {'B. Mon.': (datetime.date(1840, 1, 1),
                                                   datetime.date(1857, 12, 31))},
                          'mlz_jurisdiction': 'us;ky',
                          'name': 'Kentucky Reports, Monroe, Ben',
                          'variations': {'Ky.(B.Mon.)': 'B. Mon.',
                                         'Mon.': 'B. Mon.',
                                         'Mon.B.': 'B. Mon.',
                                         'Monroe, B.': 'B. Mon.'}}],
             'B.R.': [{'editions': {'B.R.': (datetime.date(1979, 1, 1),
                                             datetime.date.today())},
                       'mlz_jurisdiction': 'us',
                       'name': 'Bankruptcy Reporter',
                       'variations': {'B. R.': 'B.R.', 'BR': 'B.R.'}}],
             'B.T.A.': [{'editions': {'B.T.A.': (datetime.date(1924, 1, 1),
                                                 datetime.date(1942, 12, 31))},
                         'mlz_jurisdiction': 'us',
                         'name': 'Reports of the United States Board of Tax Appeals',
                         'variations': {}}],
             'B.T.A.M. (P-H)': [{'editions': {'B.T.A.M. (P-H)': (datetime.date(1928, 1, 1),
                                                                 datetime.date(1942, 12, 31))},
                                'mlz_jurisdiction': 'us',
                                'name': 'Board of Tax Appeals Memorandum Decisions',
                                'variations': {}}],
             'Bail.': [{'cite_type': 'state',
                        'editions': {'Bail.': (datetime.date(1828, 1, 1),
                                               datetime.date(1832, 12, 31))},
                        'mlz_jurisdiction': 'us;sc',
                        'name': 'South Carolina Reports, Bailey',
                        'variations': {'Bai.': 'Bail.',
                                       'Bail.L.': 'Bail.',
                                       'Bail.L.(S.C.)': 'Bail.',
                                       'Bailey': 'Bail.',
                                       'S.C.L.(Bail.)': 'Bail.'}}],
             'Bail. Eq.': [{'cite_type': 'state',
                            'editions': {'Bail. Eq.': (datetime.date(1830, 1, 1),
                                                       datetime.date(1831, 12, 31))},
                            'mlz_jurisdiction': 'us;sc',
                            'name': "South Carolina Reports, Bailey's Equity",
                            'variations': {'Bai.Eq.': 'Bail. Eq.',
                                           'Bail.Eq.(S.C.)': 'Bail. Eq.',
                                           'Bailey': 'Bail. Eq.',
                                           'Bailey Ch.': 'Bail. Eq.',
                                           'Bailey Eq.': 'Bail. Eq.',
                                           'S.C.Eq.(Bail.Eq.)': 'Bail. Eq.'}}],
             'Barb.': [{'cite_type': 'state',
                        'editions': {'Barb.': (datetime.date(1847, 1, 1),
                                               datetime.date(1877, 12, 31))},
                        'mlz_jurisdiction': 'us;ny',
                        'name': "Barbour's Supreme Court Reports",
                        'variations': {'B.': 'Barb.', 'Barb.S.C.': 'Barb.'}}],
             'Barb. Ch.': [{'cite_type': 'state',
                            'editions': {'Barb. Ch.': (datetime.date(1845, 1, 1),
                                                       datetime.date(1848, 12, 31))},
                            'mlz_jurisdiction': 'us;ny',
                            'name': "Barbour's Chancery Reports",
                            'variations': {'Barb.Ch.(N.Y.)': 'Barb. Ch.'}}],
             'Bay': [{'cite_type': 'state',
                      'editions': {'Bay': (datetime.date(1783, 1, 1),
                                           datetime.date(1804, 12, 31))},
                      'mlz_jurisdiction': 'us;sc',
                      'name': 'South Carolina Reports, Bay',
                      'variations': {'S.C.L.(Bay)': 'Bay'}}],
             'Bibb': [{'cite_type': 'state',
                       'editions': {'Bibb': (datetime.date(1808, 1, 1),
                                             datetime.date(1817, 12, 31))},
                       'mlz_jurisdiction': 'us;ky',
                       'name': 'Kentucky Reports, Bibb',
                       'variations': {'Bibb(Ky.)': 'Bibb', 'Ky.(Bibb)': 'Bibb'}}],
             'Binn.': [{'cite_type': 'state',
                        'editions': {'Binn': (datetime.date(1799, 1, 1),
                                              datetime.date(1814, 12, 31))},
                        'mlz_jurisdiction': 'us;pa',
                        'name': 'Pennsylvania State Reports, Binney',
                        'variations': {'Bin.': 'Binn', 'Binn.(Pa.)': 'Binn'}}],
             'Black': [{'cite_type': 'fed',
                        'editions': {'Black': (datetime.date(1861, 1, 1),
                                               datetime.date(1862, 12, 31))},
                        'mlz_jurisdiction': 'us',
                        'name': "Black's Supreme Court Reports",
                        'variations': {'Black R.': 'Black', 'U.S.(Black)': 'Black'}}],
             'Blackf.': [{'cite_type': 'state',
                          'editions': {'Blackf.': (datetime.date(1817, 1, 1),
                                                   datetime.date(1847, 12, 31))},
                          'mlz_jurisdiction': 'us;in',
                          'name': 'Indiana Reports, Blackford',
                          'variations': {'Black.': 'Blackf.',
                                         'Blackf.(Ind.)': 'Blackf.'}}],
             'Blume Sup. Ct. Trans.': [{'cite_type': 'state',
                                        'editions': {'Blume Sup. Ct. Trans.': (datetime.date(1805, 1, 1),
                                                                               datetime.date(1836, 12, 31))},
                                        'mlz_jurisdiction': 'us;mi',
                                        'name': 'Blume, Supreme Court Transactions',
                                        'variations': {'Blume Sup.Ct.Trans.': 'Blume Sup. Ct. Trans.'}}],
             'Blume Unrep. Op.': [{'cite_type': 'state',
                                   'editions': {'Blume Unrep. Op.': (datetime.date(1836, 1, 1),
                                                                     datetime.date(1843, 12, 31))},
                                   'mlz_jurisdiction': 'us;mi',
                                   'name': 'Blume, Unreported Opinions',
                                   'variations': {'Blume Op.': 'Blume Unrep. Op.'}}],
             'Boyce': [{'cite_type': 'state',
                        'editions': {'Boyce': (datetime.date(1909, 1, 1),
                                               datetime.date(1920, 12, 31))},
                        'mlz_jurisdiction': 'us;de',
                        'name': 'Delaware Reports, Boyce',
                        'variations': {'Del.(Boyce)': 'Boyce'}}],
             'Bradf.': [{'cite_type': 'state',
                         'editions': {'Bradf.': (datetime.date(1838, 1, 1),
                                                 datetime.date(1841, 12, 31))},
                         'mlz_jurisdiction': 'us;ia',
                         'name': 'Iowa Reports, Bradford',
                         'variations': {'Brad.': 'Bradf.', 'Bradford': 'Bradf.'}}],
             'Brayt.': [{'cite_type': 'state',
                         'editions': {'Brayt.': (datetime.date(1815, 1, 1),
                                                 datetime.date(1819, 12, 31))},
                         'mlz_jurisdiction': 'us;vt',
                         'name': 'Vermont Reports, Brayton',
                         'variations': {'Brayton (Vt.)': 'Brayt.'}}],
             'Breese': [{'cite_type': 'state',
                         'editions': {'Breese': (datetime.date(1819, 1, 1),
                                                 datetime.date(1831, 12, 31))},
                         'mlz_jurisdiction': 'us;il',
                         'name': 'Illinois Reports, Breese',
                         'variations': {'Ill.(Breese)': 'Breese'}}],
             'Brev.': [{'cite_type': 'state',
                        'editions': {'Brev.': (datetime.date(1793, 1, 1),
                                               datetime.date(1816, 12, 31))},
                        'mlz_jurisdiction': 'us;sc',
                        'name': 'South Carolina Reports, Brevard',
                        'variations': {'S.C.L.(Brev)': 'Brev.'}}],
             'Brief Times Rptr.': [{'cite_type': 'state',
                                    'editions': {'Brief Times Rptr': (datetime.date(1750, 1, 1),
                                                                      datetime.date.today())},
                                    'mlz_jurisdiction': 'us;co',
                                    'name': 'Brief Times Reporter',
                                    'variations': {}}],
             'Bur.': [{'cite_type': 'state',
                       'editions': {'Bur.': (datetime.date(1841, 1, 1),
                                             datetime.date(1843, 12, 31))},
                       'mlz_jurisdiction': 'us;wi',
                       'name': 'Wisconsin Reports, Burnett',
                       'variations': {'Burnett': 'Bur.', 'Burnett (Wis.)': 'Bur.'}}],
             'Busb.': [{'cite_type': 'state',
                        'editions': {'Busb.': (datetime.date(1852, 1, 1),
                                               datetime.date(1853, 12, 31))},
                        'mlz_jurisdiction': 'us;nc',
                        'name': "North Carolina Reports, Busbee's Law",
                        'variations': {'Busb.L.': 'Busb.', 'N.C.(Busb.)': 'Busb.'}}],
             'Busb. Eq.': [{'cite_type': 'state',
                            'editions': {'Busb. Eq.': (datetime.date(1852, 1, 1),
                                                       datetime.date(1853, 12, 31))},
                            'mlz_jurisdiction': 'us;nc',
                            'name': "North Carolina Reports, Busbee's Equity",
                            'variations': {'Busbee Eq.(N.C.)': 'Busb. Eq.',
                                           'N.C.(Busb.Eq.)': 'Busb. Eq.'}}],
             'Bush': [{'cite_type': 'state',
                       'editions': {'Bush': (datetime.date(1866, 1, 1),
                                             datetime.date(1879, 12, 31))},
                       'mlz_jurisdiction': 'us;ky',
                       'name': 'Kentucky Reports, Bush',
                       'variations': {'Bush (Ky.)': 'Bush', 'Ky.(Bush)': 'Bush'}}],
             'C.C.P.A.': [{'editions': {'C.C.P.A.': (datetime.date(1929, 1, 1),
                                                     datetime.date(1982, 12, 31))},
                           'mlz_jurisdiction': 'us',
                           'name': 'Court of Customs and Patent Appeals Reports',
                           'variations': {}}],
             'C.M.A.': [{'editions': {'C.M.A.': (datetime.date(1951, 1, 1),
                                                 datetime.date(1975, 12, 31))},
                         'mlz_jurisdiction': 'us',
                         'name': 'Decisions of the United States Court of Military Appeals',
                         'variations': {}}],
             'C.M.R.': [{'editions': {'C.M.R.': (datetime.date(1951, 1, 1),
                                                 datetime.date(1975, 12, 31))},
                         'mlz_jurisdiction': 'us',
                         'name': 'Court Martial Records',
                         'variations': {}}],
             'CO': [{'cite_type': 'neutral',
                     'editions': {'CO': (datetime.date(1750, 1, 1),
                                         datetime.date.today())},
                     'mlz_jurisdiction': 'us;co',
                     'name': 'Colorado Neutral Citation',
                     'variations': {}}],
             'Cai. Cas.': [{'cite_type': 'state',
                            'editions': {'Cai. Cas.': (datetime.date(1796, 1, 1),
                                                       datetime.date(1805, 12, 31))},
                            'mlz_jurisdiction': 'us;ny',
                            'name': "Caines' Cases",
                            'variations': {'Cai.': 'Cai. Cas.',
                                           'Cai.Cas.Err.': 'Cai. Cas.',
                                           'Cain.': 'Cai. Cas.',
                                           'Caines': 'Cai. Cas.',
                                           'Caines (N.Y.)': 'Cai. Cas.',
                                           'Caines Cas.': 'Cai. Cas.',
                                           'N.Y.Cas.Err.': 'Cai. Cas.'}}],
             'Cai. R.': [{'cite_type': 'state',
                          'editions': {'Cai. R.': (datetime.date(1803, 1, 1),
                                                   datetime.date(1805, 12, 31))},
                          'mlz_jurisdiction': 'us;ny',
                          'name': "Caines' Reports",
                          'variations': {'Cai.R.': 'Cai. R.'}}],
             'Cal.': [{'cite_type': 'state',
                       'editions': {'Cal.': (datetime.date(1850, 1, 1),
                                             datetime.date(1934, 12, 31)),
                                    'Cal. 2d': (datetime.date(1934, 1, 1),
                                                datetime.date(1969, 12, 31)),
                                    'Cal. 3d': (datetime.date(1969, 1, 1),
                                                datetime.date(1991, 12, 31)),
                                    'Cal. 4th': (datetime.date(1991, 1, 1),
                                                 datetime.date.today())},
                       'mlz_jurisdiction': 'us;ca',
                       'name': 'California Reports',
                       'variations': {'Cal.2d': 'Cal. 2d',
                                      'Cal.3d': 'Cal. 3d',
                                      'Cal.4th': 'Cal. 4th'}}],
             'Cal. App.': [{'cite_type': 'state',
                            'editions': {'Cal. App.': (datetime.date(1905, 1, 1),
                                                       datetime.date(1934, 12, 31)),
                                         'Cal. App. 2d': (datetime.date(1934, 1, 1),
                                                          datetime.date(1969, 12, 31)),
                                         'Cal. App. 3d': (datetime.date(1969, 1, 1),
                                                          datetime.date(1991, 12, 31)),
                                         'Cal. App. 4th': (datetime.date(1991, 1, 1),
                                                           datetime.date.today())},
                            'mlz_jurisdiction': 'us;ca',
                            'name': 'California Appellate Reports',
                            'variations': {'Cal. App.2d': 'Cal. App. 2d',
                                           'Cal. App.3d': 'Cal. App. 3d',
                                           'Cal. App.4th': 'Cal. App. 4th',
                                           'Cal.App.': 'Cal. App.',
                                           'Cal.App. 2d': 'Cal. App. 2d',
                                           'Cal.App. 3d': 'Cal. App. 3d',
                                           'Cal.App. 4th': 'Cal. App. 4th',
                                           'Cal.App.2d': 'Cal. App. 2d',
                                           'Cal.App.3d': 'Cal. App. 3d',
                                           'Cal.App.4th': 'Cal. App. 4th'}}],
             'Cal. App. Supp.': [{'cite_type': 'state',
                                  'editions': {'Cal. App. Supp.': (datetime.date(1929, 1, 1),
                                                                   datetime.date.today()),
                                               'Cal. App. Supp. 2d': (datetime.date(1929, 1, 1),
                                                                      datetime.date.today()),
                                               'Cal. App. Supp. 3d': (datetime.date(1929, 1, 1),
                                                                      datetime.date.today())},
                                  'mlz_jurisdiction': 'us;ca',
                                  'name': 'California Appellate Reports, Supplement',
                                  'variations': {'Cal.App. 2d Supp.': 'Cal. App. Supp. 2d',
                                                 'Cal.App. 3d Supp.': 'Cal. App. Supp. 3d',
                                                 'Cal.App. Supp. 2d': 'Cal. App. Supp. 2d',
                                                 'Cal.App. Supp. 3d': 'Cal. App. Supp. 3d',
                                                 'Cal.App. Supp.2d': 'Cal. App. Supp. 2d',
                                                 'Cal.App. Supp.3d': 'Cal. App. Supp. 3d',
                                                 'Cal.App.2d Supp.': 'Cal. App. Supp. 2d',
                                                 'Cal.App.3d Supp.': 'Cal. App. Supp. 3d',
                                                 'Cal.App.Supp.': 'Cal. App. Supp.',
                                                 'Cal.App.Supp.2d': 'Cal. App. Supp. 2d'}}],
             'Cal. Rptr.': [{'cite_type': 'state',
                             'editions': {'Cal. Rptr.': (datetime.date(1959, 1, 1),
                                                         datetime.date(1991, 12, 31)),
                                          'Cal. Rptr. 2d': (datetime.date(1992, 1, 1),
                                                            datetime.date(2003, 12, 31)),
                                          'Cal. Rptr. 3d': (datetime.date(2003, 1, 1),
                                                            datetime.date.today())},
                             'mlz_jurisdiction': 'us;ca',
                             'name': "West's California Reporter",
                             'variations': {'Cal. Rptr.2d': 'Cal. Rptr. 2d',
                                            'Cal. Rptr.3d': 'Cal. Rptr. 3d',
                                            'Cal.Rptr.': 'Cal. Rptr.',
                                            'Cal.Rptr. 2d': 'Cal. Rptr. 2d',
                                            'Cal.Rptr. 3d': 'Cal. Rptr. 3d',
                                            'Cal.Rptr.2d': 'Cal. Rptr. 2d',
                                            'Cal.Rptr.3d': 'Cal. Rptr. 3d'}}],
             'Cal. Unrep.': [{'cite_type': 'state',
                              'editions': {'Cal. Unrep.': (datetime.date(1855, 1, 1),
                                                           datetime.date(1910, 12, 31))},
                              'mlz_jurisdiction': 'us;ca',
                              'name': 'California Unreported Cases',
                              'variations': {'Cal.Unrep.Cas.': 'Cal. Unrep.'}}],
             'Call': [{'cite_type': 'state',
                       'editions': {'Call': (datetime.date(1779, 1, 1),
                                             datetime.date(1825, 12, 31))},
                       'mlz_jurisdiction': 'us;va',
                       'name': 'Virginia Reports, Call',
                       'variations': {'Call (Va.)': 'Call', 'Va.(Call)': 'Call'}}],
             'Cam. & Nor.': [{'cite_type': 'state',
                              'editions': {'Cam. & Nor.': (datetime.date(1800, 1, 1),
                                                           datetime.date(1804, 12, 31))},
                              'mlz_jurisdiction': 'us;nc',
                              'name': 'North Carolina Reports, Conference by Cameron & Norwood',
                              'variations': {'Cam.& N.': 'Cam. & Nor.',
                                             'N.C.(Cam.& Nor.)': 'Cam. & Nor.',
                                             'N.C.Conf.': 'Cam. & Nor.',
                                             'N.C.Conf.Rep.': 'Cam. & Nor.'}}],
             'Car. L. Rep.': [{'cite_type': 'state',
                               'editions': {'Car. L. Rep.': (datetime.date(1811, 1, 1),
                                                             datetime.date(1816, 12, 31))},
                               'mlz_jurisdiction': 'us;nc',
                               'name': 'Carolina Law Repository',
                               'variations': {'Car.Law.Repos.': 'Car. L. Rep.',
                                              'N.C.(Car.L.Rep.)': 'Car. L. Rep.'}}],
             'Chand.': [{'cite_type': 'state',
                         'editions': {'Chand.': (datetime.date(1849, 1, 1),
                                                 datetime.date(1852, 12, 31))},
                         'mlz_jurisdiction': 'us;wi',
                         'name': 'Wisconsin Reports, Chandler',
                         'variations': {'Chand.(Wis.)': 'Chand.', 'Chandl.': 'Chand.'}}],
             'Chev.': [{'cite_type': 'state',
                        'editions': {'Chev.': (datetime.date(1839, 1, 1),
                                               datetime.date(1840, 12, 31))},
                        'mlz_jurisdiction': 'us;sc',
                        'name': 'South Carolina Reports, Cheves',
                        'variations': {'Cheves': 'Chev.',
                                       'Cheves L.(S.C.)': 'Chev.',
                                       'S.C.L.(Chev.)': 'Chev.'}}],
             'Chev. Eq.': [{'cite_type': 'state',
                            'editions': {'Chev. Eq.': (datetime.date(1839, 1, 1),
                                                       datetime.date(1840, 12, 31))},
                            'mlz_jurisdiction': 'us;sc',
                            'name': "South Carolina Reports, Cheves' Equity",
                            'variations': {'Chev.Ch.': 'Chev. Eq.',
                                           'Cheves Eq.(S.C.)': 'Chev. Eq.',
                                           'S.C.Eq.(Chev.Eq.)': 'Chev. Eq.'}}],
             'Cl. Ch.': [{'cite_type': 'state',
                          'editions': {'Cl. Ch.': (datetime.date(1839, 1, 1),
                                                   datetime.date(1841, 12, 31))},
                          'mlz_jurisdiction': 'us;ny',
                          'name': "Clarke's Chancery Reports",
                          'variations': {'Cl.R.': 'Cl. Ch.',
                                         'Clarke': 'Cl. Ch.',
                                         'Clarke Ch.': 'Cl. Ch.',
                                         'Clarke Ch.(N.Y.)': 'Cl. Ch.'}}],
             'Cl. Ct.': [{'editions': {'Cl. Ct.': (datetime.date(1983, 1, 1),
                                                   datetime.date(1992, 12, 31))},
                          'mlz_jurisdiction': 'us',
                          'name': 'United States Claims Court Reporter',
                          'variations': {}}],
             'Cold.': [{'cite_type': 'state',
                        'editions': {'Cold.': (datetime.date(1860, 1, 1),
                                               datetime.date(1870, 12, 31))},
                        'mlz_jurisdiction': 'us;tn',
                        'name': 'Tennessee Reports, Coldwell',
                        'variations': {'Col.': 'Cold.',
                                       'Coldw.': 'Cold.',
                                       'Tenn.(Cold.)': 'Cold.'}}],
             'Cole. & Cai. Cas.': [{'cite_type': 'state',
                                    'editions': {'Cole. & Cai. Cas.': (datetime.date(1794, 1, 1),
                                                                       datetime.date(1805, 12, 31))},
                                    'mlz_jurisdiction': 'us;ny',
                                    'name': "Coleman & Caines' Cases",
                                    'variations': {'C.& C.': 'Cole. & Cai. Cas.',
                                                   'Col.& C.Cas.': 'Cole. & Cai. Cas.',
                                                   'Col.& Cai.': 'Cole. & Cai. Cas.',
                                                   'Col.& Caines Cas.(N.Y.)': 'Cole. & Cai. Cas.',
                                                   'Cole.& C.Cas.': 'Cole. & Cai. Cas.',
                                                   'Cole.& Cai.': 'Cole. & Cai. Cas.',
                                                   'Colem.& C.Cas.': 'Cole. & Cai. Cas.'}}],
             'Cole. Cas.': [{'cite_type': 'state',
                             'editions': {'Cole. Cas.': (datetime.date(1791, 1, 1),
                                                         datetime.date(1800, 12, 31))},
                             'mlz_jurisdiction': 'us;ny',
                             'name': "Coleman's Cases",
                             'variations': {'C.C.': 'Cole. Cas.',
                                            'Col.Cas.': 'Cole. Cas.',
                                            'Col.Cas.(N.Y.)': 'Cole. Cas.',
                                            'Cole.Cas.Pr.': 'Cole. Cas.',
                                            'Colem.Cas.': 'Cole. Cas.'}}],
             'Colo.': [{'cite_type': 'state',
                        'editions': {'Colo.': (datetime.date(1864, 1, 1),
                                               datetime.date(1980, 12, 31))},
                        'mlz_jurisdiction': 'us;co',
                        'name': 'Colorado Reports',
                        'variations': {'Col.': 'Colo.'}}],
             'Colo. Law.': [{'cite_type': 'state',
                             'editions': {'Colo. Law.': (datetime.date(1750, 1, 1),
                                                         datetime.date.today())},
                             'mlz_jurisdiction': 'us;co',
                             'name': 'Colorado Lawyer',
                             'variations': {'Colorado Law.': 'Colo. Law.'}}],
             'Conn.': [{'cite_type': 'state',
                        'editions': {'Conn.': (datetime.date(1814, 1, 1),
                                               datetime.date.today())},
                        'mlz_jurisdiction': 'us;ct',
                        'name': 'Connecticut Reports',
                        'variations': {}}],
             'Conn. App.': [{'cite_type': 'state',
                             'editions': {'Conn. App.': (datetime.date(1983, 1, 1),
                                                         datetime.date.today())},
                             'mlz_jurisdiction': 'us;ct',
                             'name': 'Connecticut Appellate Reports',
                             'variations': {}}],
             'Conn. Cir. Ct': [{'cite_type': 'state',
                                'editions': {'Conn. Cir. Ct': (datetime.date(1961, 1, 1),
                                                               datetime.date(1974, 12, 31))},
                                'mlz_jurisdiction': 'us;ct',
                                'name': 'Connecticut Circuit Court Reports',
                                'variations': {}}],
             'Conn. L. Rptr.': [{'cite_type': 'state',
                                 'editions': {'Conn. L. Rptr': (datetime.date(1990, 1, 1),
                                                                datetime.date.today())},
                                 'mlz_jurisdiction': 'us;ct',
                                 'name': 'Connecticut Law Reporter',
                                 'variations': {}}],
             'Conn. Super. Ct.': [{'cite_type': 'state',
                                   'editions': {'Conn. Super Ct.': (datetime.date(1986, 1, 1),
                                                                    datetime.date(1994, 12, 31))},
                                   'mlz_jurisdiction': 'us;ct',
                                   'name': 'Connecticut Superior Court Reports',
                                   'variations': {}}],
             'Conn. Supp.': [{'cite_type': 'state',
                              'editions': {'Conn. Supp.': (datetime.date(1935, 1, 1),
                                                           datetime.date.today())},
                              'mlz_jurisdiction': 'us;ct',
                              'name': 'Connecticut Supplement',
                              'variations': {}}],
             'Cooke': [{'cite_type': 'state',
                        'editions': {'Cooke': (datetime.date(1811, 1, 1),
                                               datetime.date(1814, 12, 31))},
                        'mlz_jurisdiction': 'us;tn',
                        'name': 'Tennessee Reports, Cooke',
                        'variations': {'Cooke (Tenn.)': 'Cooke',
                                       'Tenn.(Cooke)': 'Cooke'}}],
             'Cow.': [{'cite_type': 'state',
                       'editions': {'Cow.': (datetime.date(1823, 1, 1),
                                             datetime.date(1829, 12, 31))},
                       'mlz_jurisdiction': 'us;ny',
                       'name': "Cowen's Reports",
                       'variations': {'C.': 'Cow.', 'Cow.N.Y.': 'Cow.'}}],
             'Cranch': [{'cite_type': 'fed',
                         'editions': {'Cranch': (datetime.date(1801, 1, 1),
                                                 datetime.date(1815, 12, 31))},
                         'mlz_jurisdiction': 'us',
                         'name': "Cranch's Supreme Court Reports",
                         'variations': {'Cr.': 'Cranch',
                                        'Cra.': 'Cranch',
                                        'Cranch (US)': 'Cranch',
                                        'U.S.(Cranch)': 'Cranch'}},
                        {'cite_type': 'state',
                         'editions': {'Cranch': (datetime.date(1801, 1, 1),
                                                 datetime.date(1841, 12, 31))},
                         'mlz_jurisdiction': 'us;dc',
                         'name': 'District of Columbia Reports, Cranch',
                         'variations': {'Cranch C.C.': 'Cranch',
                                        'Cranch D.C.': 'Cranch',
                                        'D.C.(Cranch)': 'Cranch'}}],
             'Ct. Cl.': [{'cite_type': 'fed',
                          'editions': {'Ct. Cl.': (datetime.date(1863, 1, 1),
                                                   datetime.date(1982, 12, 31))},
                          'mlz_jurisdiction': 'us',
                          'name': 'Court of Claims Reports',
                          'variations': {'Court Cl.': 'Ct. Cl.', 'Ct.Cl.': 'Ct. Cl.'}}],
             'Ct. Cust.': [{'editions': {'Ct. Cust.': (datetime.date(1910, 1, 1),
                                                       datetime.date(1929, 12, 31))},
                            'mlz_jurisdiction': 'us',
                            'name': 'Court of Customs Appeals Reports',
                            'variations': {}}],
             "Ct. Int'l Trade": [{'cite_type': 'fed',
                                  'editions': {"Ct. Int'l Trade": (datetime.date(1980, 1, 1),
                                                                   datetime.date.today())},
                                  'mlz_jurisdiction': 'us',
                                  'name': 'Court of International Trade Reports',
                                  'variations': {"Ct.Int'l Trade": "Ct. Int'l Trade"}}],
             'Cush.': [{'cite_type': 'state',
                        'editions': {'Cush.': (datetime.date(1848, 1, 1),
                                               datetime.date(1853, 12, 31))},
                        'mlz_jurisdiction': 'us;ma',
                        'name': 'Massachusetts Reports, Cushing',
                        'variations': {'Cush.(Mass.)': 'Cush.',
                                       'Cushing': 'Cush.',
                                       'Mass.(Cush.)': 'Cush.'}}],
             'Cust. B. & Dec.': [{'editions': {'Cust. B. & Dec.': (datetime.date(1967, 1, 1),
                                                                   datetime.date.today())},
                                  'mlz_jurisdiction': 'us',
                                  'name': 'Customs Bulletin and Decisions',
                                  'variations': {}}],
             'Cust. Ct.': [{'editions': {'Cust. Ct.': (datetime.date(1938, 1, 1),
                                                       datetime.date(1980, 12, 31))},
                            'mlz_jurisdiction': 'us',
                            'name': 'Customs Court Reports',
                            'variations': {}}],
             'D. Chip.': [{'cite_type': 'state',
                           'editions': {'D. Chip.': (datetime.date(1789, 1, 1),
                                                     datetime.date(1824, 12, 31))},
                           'mlz_jurisdiction': 'us;vt',
                           'name': 'Vermont Reports, Chipman, D.',
                           'variations': {'Chip.': 'D. Chip.',
                                          'Chip.(Vt.)': 'D. Chip.',
                                          'Chip.D.': 'D. Chip.',
                                          'D.Chip.(Vt.)': 'D. Chip.',
                                          'D.Chipm.': 'D. Chip.'}}],
             'Dakota': [{'cite_type': 'state',
                         'editions': {'Dakota': (datetime.date(1867, 1, 1),
                                                 datetime.date(1889, 12, 31))},
                         'mlz_jurisdiction': 'us;nd',
                         'name': 'Dakota Reports',
                         'variations': {'Dak.': 'Dakota'}}],
             'Dall.': [{'cite_type': 'fed',
                        'editions': {'Dall': (datetime.date(1790, 1, 1),
                                              datetime.date(1880, 12, 31))},
                        'mlz_jurisdiction': 'us',
                        'name': "Dallas' Supreme Court Reports",
                        'variations': {'Dal.': 'Dall.',
                                       'Dall.S.C.': 'Dall.',
                                       'Dallas': 'Dall.',
                                       'U.S.(Dall.)': 'Dall.'}},
                       {'cite_type': 'state',
                        'editions': {'Dall.': (datetime.date(1754, 1, 1),
                                               datetime.date(1806, 12, 31))},
                        'mlz_jurisdiction': 'us;pa',
                        'name': 'Pennsylvania State Reports, Dallas',
                        'variations': {'D.': 'Dall.',
                                       'Dal.': 'Dall.',
                                       'Dallas': 'Dall.'}}],
             'Dallam': [{'cite_type': 'state',
                         'editions': {'Dallam': (datetime.date(1840, 1, 1),
                                                 datetime.date(1844, 12, 31))},
                         'mlz_jurisdiction': 'us;tx',
                         'name': "Digest of the Laws of Texas (Dallam's Opinions)",
                         'variations': {'Dall.(Tex.)': 'Dallam',
                                        'Dall.Dig.': 'Dallam',
                                        'Dallam Dig.(Tex.)': 'Dallam'}}],
             'Dana': [{'cite_type': 'state',
                       'editions': {'Dana': (datetime.date(1833, 1, 1),
                                             datetime.date(1840, 12, 31))},
                       'mlz_jurisdiction': 'us;ky',
                       'name': 'Kentucky Reports, Dana',
                       'variations': {'Dan.': 'Dana', 'Ky.(Dana)': 'Dana'}}],
             'Day': [{'editions': {'Day': (datetime.date(1802, 1, 1),
                                           datetime.date(1813, 12, 31))},
                      'mlz_jurisdiction': 'uc;ct',
                      'name': "Day's Connecticut Reports",
                      'variations': {'Day (Conn)': 'Day'}}],
             'Del.': [{'cite_type': 'state',
                       'editions': {'Del.': (datetime.date(1920, 1, 1),
                                             datetime.date(1966, 12, 31))},
                       'mlz_jurisdiction': 'us;de',
                       'name': 'Delaware Reports',
                       'variations': {}}],
             'Del. Cas.': [{'editions': {'Del. Cas.': (datetime.date(1792, 1, 1),
                                                       datetime.date(1830, 12, 31))},
                            'mlz_jurisdiction': '',
                            'name': 'Delaware Cases',
                            'variations': {}}],
             'Del. Ch.': [{'cite_type': 'state',
                           'editions': {'Del. Ch.': (datetime.date(1814, 1, 1),
                                                     datetime.date(1968, 12, 31))},
                           'mlz_jurisdiction': 'us;de',
                           'name': 'Delaware Chancery Reports',
                           'variations': {}}],
             'Denio': [{'cite_type': 'state',
                        'editions': {'Denio': (datetime.date(1845, 1, 1),
                                               datetime.date(1848, 12, 31))},
                        'mlz_jurisdiction': 'us;ny',
                        'name': "Denio's Reports",
                        'variations': {'Den.': 'Denio'}}],
             'Des.': [{'cite_type': 'state',
                       'editions': {'Des.': (datetime.date(1784, 1, 1),
                                             datetime.date(1817, 12, 31))},
                       'mlz_jurisdiction': 'us;sc',
                       'name': "South Carolina Reports, Desaussure's Equity",
                       'variations': {'Desaus.': 'Des.',
                                      'Desaus.Eq.': 'Des.',
                                      'S.C.Eq.(Des.)': 'Des.'}}],
             'Dev.': [{'cite_type': 'state',
                       'editions': {'Dev.': (datetime.date(1826, 1, 1),
                                             datetime.date(1834, 12, 31))},
                       'mlz_jurisdiction': 'us;nc',
                       'name': "North Carolina Reports, Devereux's Law",
                       'variations': {'Dev.L.': 'Dev.', 'N.C.(Dev.)': 'Dev.'}}],
             'Dev. & Bat.': [{'cite_type': 'state',
                              'editions': {'Dev. & Bat.': (datetime.date(1834, 1, 1),
                                                           datetime.date(1839, 12, 31))},
                              'mlz_jurisdiction': 'us;nc',
                              'name': "North Carolina Reports, Devereux & Battle's Law",
                              'variations': {'D.& B.': 'Dev. & Bat.',
                                             'Dev.& B.': 'Dev. & Bat.',
                                             'Dev.& B.L.': 'Dev. & Bat.',
                                             'N.C.(Dev.& Bat.)': 'Dev. & Bat.'}}],
             'Dev. & Bat. Eq.': [{'cite_type': 'state',
                                  'editions': {'Dev. & Bat. Eq.': (datetime.date(1834, 1, 1),
                                                                   datetime.date(1839, 12, 31))},
                                  'mlz_jurisdiction': 'us;nc',
                                  'name': "North Carolina Reports, Devereux & Battle's Equity",
                                  'variations': {'D.& B.': 'Dev. & Bat. Eq.',
                                                 'Dev.& B.': 'Dev. & Bat. Eq.',
                                                 'Dev.& B.Eq.': 'Dev. & Bat. Eq.',
                                                 'N.C.(Dev.& Bat.Eq.)': 'Dev. & Bat. Eq.'}}],
             'Dev. Eq.': [{'cite_type': 'state',
                           'editions': {'Dev. Eq.': (datetime.date(1826, 1, 1),
                                                     datetime.date(1834, 12, 31))},
                           'mlz_jurisdiction': 'us;nc',
                           'name': "North Carolina Reports, Devereux's Equity",
                           'variations': {'Dev.': 'Dev. Eq.',
                                          'N.C.(Dev.Eq.)': 'Dev. Eq.'}}],
             'Doug.': [{'cite_type': 'state',
                        'editions': {'Doug.': (datetime.date(1843, 1, 1),
                                               datetime.date(1847, 12, 31))},
                        'mlz_jurisdiction': 'us;mi',
                        'name': 'Michigan Reports, Douglass',
                        'variations': {'Doug.(Mich.)': 'Doug.',
                                       'Dougl.(Mich.)': 'Doug.'}}],
             'Dud.': [{'cite_type': 'state',
                       'editions': {'Dud.': (datetime.date(1837, 1, 1),
                                             datetime.date(1838, 12, 31))},
                       'mlz_jurisdiction': 'us;sc',
                       'name': 'South Carolina Reports, Dudley',
                       'variations': {'Dud.(S.C.)': 'Dud.',
                                      'Dud.L.': 'Dud.',
                                      'Dud.L.(S.C.)': 'Dud.',
                                      'Dudl.': 'Dud.',
                                      'S.C.L.(Dud.)': 'Dud.'}}],
             'Dud. Eq.': [{'cite_type': 'state',
                           'editions': {'Dud. Eq.': (datetime.date(1837, 1, 1),
                                                     datetime.date(1838, 12, 31))},
                           'mlz_jurisdiction': 'us;sc',
                           'name': "South Carolina Reports, Dudley's Equity",
                           'variations': {'Dud.Ch.': 'Dud. Eq.',
                                          'Dud.Eq.(S.C.)': 'Dud. Eq.',
                                          'Dudl.': 'Dud. Eq.',
                                          'S.C.Eq.(Dud.Eq.)': 'Dud. Eq.'}}],
             'Duv.': [{'cite_type': 'state',
                       'editions': {'Duv.': (datetime.date(1863, 1, 1),
                                             datetime.date(1866, 12, 31))},
                       'mlz_jurisdiction': 'us;ky',
                       'name': 'Kentucky Reports, Duvall',
                       'variations': {'Ky.(Duv.)': 'Duv.'}}],
             'Edm. Sel. Cas.': [{'cite_type': 'state',
                                 'editions': {'Edm. Sel. Cas.': (datetime.date(1834, 1, 1),
                                                                 datetime.date(1853, 12, 31))},
                                 'mlz_jurisdiction': 'us;ny',
                                 'name': "Edmond's Select Cases",
                                 'variations': {'Edm.Sel.Ca.': 'Edm. Sel. Cas.',
                                                'Edm.Sel.Cas.(N.Y.)': 'Edm. Sel. Cas.',
                                                'Edmond': 'Edm. Sel. Cas.'}}],
             'Edw. Ch.': [{'cite_type': 'state',
                           'editions': {'Edw. Ch.': (datetime.date(1831, 1, 1),
                                                     datetime.date(1850, 12, 31))},
                           'mlz_jurisdiction': 'us;ny',
                           'name': "Edwards' Chancery Reports",
                           'variations': {'Ed.C.R.': 'Edw. Ch.',
                                          'Ed.Ch.': 'Edw. Ch.',
                                          'Edw.': 'Edw. Ch.',
                                          'Edw.Ch.(N.Y.)': 'Edw. Ch.'}}],
             'F.': [{'cite_type': 'fed',
                     'editions': {'F.': (datetime.date(1880, 1, 1),
                                         datetime.date(1924, 12, 31)),
                                  'F.2d': (datetime.date(1924, 1, 1),
                                           datetime.date(1993, 12, 31)),
                                  'F.3d': (datetime.date(1993, 1, 1),
                                           datetime.date.today())},
                     'mlz_jurisdiction': 'us',
                     'name': 'Federal Reporter',
                     'variations': {'F. 2d': 'F.2d',
                                    'F. 3d': 'F.3d',
                                    'F.2d.': 'F.2d',
                                    'Fed.R.': 'F.',
                                    'Fed.R.2d': 'F.2d',
                                    'Fed.R.3d': 'F.3d',
                                    'Fed.Rep.': 'F.',
                                    'Fed.Rep.2d': 'F.2d',
                                    'Fed.Rep.3d': 'F.3d'}}],
             'F. App\'x': [{'editions': {'F. App\'x': (datetime.date(2001, 1, 1),
                                                       datetime.date.today())},
                            'mlz_jurisdiction': 'us',
                            'name': 'Federal Appendix',
                            'variations': {}}],
             'F. Cas.': [{'cite_type': 'fed',
                          'editions': {'F. Cas.': (datetime.date(1789, 1, 1),
                                                   datetime.date(1880, 1, 1))},
                          'mlz_jurisdiction': 'us',
                          'name': 'Federal Cases',
                          'variations': {'F.C.': 'F. Cas.',
                                         'F.Cas.': 'F. Cas.',
                                         'Fed.Ca.': 'F. Cas.'}}],
             'F. Supp.': [{'cite_type': 'fed',
                           'editions': {'F. Supp.': (datetime.date(1932, 1, 1),
                                                     datetime.date(1988, 12, 31)),
                                        'F. Supp. 2d': (datetime.date(1988, 1, 1),
                                                        datetime.date.today())},
                           'mlz_jurisdiction': 'us',
                           'name': 'Federal Supplement',
                           'variations': {'F. Supp.2d': 'F. Supp. 2d',
                                          'F.Supp.': 'F. Supp.',
                                          'F.Supp. 2d': 'F. Supp. 2d',
                                          'F.Supp.2d': 'F. Supp. 2d'}}],
             'F.R.D.': [{'editions': {'F.R.D.': (datetime.date(2001, 1, 1),
                                                 datetime.date.today())},
                         'mlz_jurisdiction': 'us',
                         'name': 'Federal Rules Decisions',
                         'variations': {}}],
             'FL': [{'cite_type': 'neutral',
                     'editions': {'FL': (datetime.date(1750, 1, 1),
                                         datetime.date.today())},
                     'mlz_jurisdiction': 'us;fl',
                     'name': 'Florida Neutral Citation',
                     'variations': {}}],
             'Fed. Cl.': [{'cite_type': 'fed',
                           'editions': {'Fed. Cl.': (datetime.date(1992, 1, 1),
                                                     datetime.date.today())},
                           'mlz_jurisdiction': 'us',
                           'name': 'United States Claims Court Reporter',
                           'variations': {'Fed.Cl.': 'Fed. Cl.'}}],
             'Fed. R. Serv.': [{'editions': {'Fed. R. Serv.': (datetime.date(1938, 1, 1),
                                                               datetime.date.today()),
                                             'Fed. R. Serv. 2d': (datetime.date(1938, 1, 1),
                                                                  datetime.date.today()),
                                             'Fed. R. Serv. 3d': (datetime.date(1938, 1, 1),
                                                                  datetime.date.today())},
                                'mlz_jurisdiction': 'us',
                                'name': 'Federal Rules Service',
                                'variations': {'Fed. R. Serv. (Callaghan)': 'Fed. R. Serv.',
                                               'Fed. R. Serv. 2d (Callaghan)': 'Fed. R. Serv. 2d',
                                               'Fed. R. Serv. 3d (West)': 'Fed. R. Serv. 3d'}}],
             'Fla.': [{'cite_type': 'state',
                       'editions': {'Fla.': (datetime.date(1846, 1, 1),
                                             datetime.date(1948, 12, 31))},
                       'mlz_jurisdiction': 'us;fl',
                       'name': 'Florida Reports',
                       'variations': {'Flor.': 'Fla.', 'Florida': 'Fla.'}}],
             'Fla. L. Weekly': [{'cite_type': 'state',
                                 'editions': {'Fla. L. Weekly': (datetime.date(1978, 1, 1),
                                                                 datetime.date.today())},
                                 'mlz_jurisdiction': 'us;fl',
                                 'name': 'Florida Law Weekly',
                                 'variations': {}}],
             'Fla. L. Weekly Supp.': [{'cite_type': 'state',
                                       'editions': {'Fla. L. Weekly Supp.': (datetime.date(1992, 1, 1),
                                                                             datetime.date.today())},
                                       'mlz_jurisdiction': 'us;fl',
                                       'name': 'Florida Law Weekly Supplement',
                                       'variations': {}}],
             'Fla. Supp.': [{'cite_type': 'state',
                             'editions': {'Fla. Supp.': (datetime.date(1948, 1, 1),
                                                         datetime.date(1981, 12, 31)),
                                          'Fla. Supp. 2d': (datetime.date(1983, 1, 1),
                                                            datetime.date(1992, 12, 31))},
                             'mlz_jurisdiction': 'us;fl',
                             'name': 'Florida Supplement',
                             'variations': {'Fl.S.': 'Fla. Supp.'}}],
             'G. & J.': [{'cite_type': 'state',
                          'editions': {'G. & J.': (datetime.date(1829, 1, 1),
                                                   datetime.date(1842, 12, 31))},
                          'mlz_jurisdiction': 'us;md',
                          'name': 'Maryland Reports, Gill & Johnson',
                          'variations': {}}],
             'Ga.': [{'cite_type': 'state',
                      'editions': {'Ga.': (datetime.date(1846, 1, 1),
                                           datetime.date.today())},
                      'mlz_jurisdiction': 'us;ga',
                      'name': 'Georgia Reports',
                      'variations': {}}],
             'Ga. App.': [{'cite_type': 'state',
                           'editions': {'Ga. App.': (datetime.date(1907, 1, 1),
                                                     datetime.date.today())},
                           'mlz_jurisdiction': 'us;ga',
                           'name': 'Georgia Appeals Reports',
                           'variations': {}}],
             'Gild.': [{'cite_type': 'state',
                        'editions': {'Gild.': (datetime.date(1883, 1, 1),
                                               datetime.date(1889, 12, 31))},
                        'mlz_jurisdiction': 'us;nm',
                        'name': 'Gildersleeve Reports',
                        'variations': {'Gildersleeve': 'Gild.',
                                       'Gildr.': 'Gild.',
                                       'N.M.(G.)': 'Gild.',
                                       'N.M.(Gild.)': 'Gild.'}}],
             'Gill': [{'cite_type': 'state',
                       'editions': {'Gill': (datetime.date(1843, 1, 1),
                                             datetime.date(1851, 12, 31))},
                       'mlz_jurisdiction': 'us;md',
                       'name': 'Maryland Reports, Gill',
                       'variations': {}}],
             'Gilm.': [{'cite_type': 'state',
                        'editions': {'Gilm.': (datetime.date(1844, 1, 1),
                                               datetime.date(1849, 12, 31))},
                        'mlz_jurisdiction': 'us;il',
                        'name': 'Illinois Reports, Gilman',
                        'variations': {'Gilm.(Ill.)': 'Gilm.',
                                       'Gilman': 'Gilm.',
                                       'Ill.(Gilm.)': 'Gilm.'}}],
             'Gilmer': [{'cite_type': 'state',
                         'editions': {'Gilmer': (datetime.date(1820, 1, 1),
                                                 datetime.date(1821, 12, 31))},
                         'mlz_jurisdiction': 'us;va',
                         'name': 'Virginia Reports, Gilmer',
                         'variations': {'Gil.': 'Gilmer',
                                        'Gilm.': 'Gilmer',
                                        'Gilmer (Va.)': 'Gilmer',
                                        'Va.(Gilmer)': 'Gilmer'}}],
             'Grant': [{'cite_type': 'state',
                        'editions': {'Grant': (datetime.date(1814, 1, 1),
                                               datetime.date(1863, 12, 31))},
                        'mlz_jurisdiction': 'us;pa',
                        'name': 'Pennsylvania State Reports, Grant',
                        'variations': {'Gr.': 'Grant',
                                       'Grant (Pa.)': 'Grant',
                                       'Grant Cas.': 'Grant',
                                       'Grant Cas.(Pa.)': 'Grant',
                                       'Grant Pa.': 'Grant'}}],
             'Gratt.': [{'cite_type': 'state',
                         'editions': {'Gratt.': (datetime.date(1844, 1, 1),
                                                 datetime.date(1880, 12, 31))},
                         'mlz_jurisdiction': 'us;va',
                         'name': 'Virginia Reports, Grattan',
                         'variations': {'Gratt.(Va.)': 'Gratt.',
                                        'Va.(Gratt.)': 'Gratt.'}}],
             'Gray': [{'cite_type': 'state',
                       'editions': {'Gray': (datetime.date(1854, 1, 1),
                                             datetime.date(1860, 12, 31))},
                       'mlz_jurisdiction': 'us;ma',
                       'name': 'Massachusetts Reports, Gray',
                       'variations': {'Gray (Mass.)': 'Gray', 'Mass.(Gray)': 'Gray'}}],
             'Greene': [{'editions': {'Greene': (datetime.date(1847, 1, 1),
                                                 datetime.date(1854, 12, 31))},
                         'mlz_jurisdiction': 'ui;ia',
                         'name': 'Iowa Reports, Greene',
                         'variations': {'Greene G.(Iowa)': 'Greene'}}],
             'Guam': [{'cite_type': 'state',
                       'editions': {'Guam': (datetime.date(1955, 1, 1),
                                             datetime.date.today())},
                       'mlz_jurisdiction': 'us;gu',
                       'name': 'Guam Reports',
                       'variations': {}}],
             'Gunby': [{'cite_type': 'state',
                        'editions': {'Gunby': (datetime.date(1885, 1, 1),
                                               datetime.date(1885, 12, 31))},
                        'mlz_jurisdiction': 'us;la',
                        'name': 'Louisiana Court of Appeals Reports, Gunby',
                        'variations': {'Gunby (La.)': 'Gunby'}}],
             'H. & G.': [{'cite_type': 'state',
                          'editions': {'H. & G.': (datetime.date(1826, 1, 1),
                                                   datetime.date(1829, 12, 31))},
                          'mlz_jurisdiction': 'us;md',
                          'name': 'Maryland Reports, Harris and Gill',
                          'variations': {}}],
             'H. & J.': [{'cite_type': 'state',
                          'editions': {'H. & J.': (datetime.date(1800, 1, 1),
                                                   datetime.date(1826, 12, 31))},
                          'mlz_jurisdiction': 'us;md',
                          'name': 'Maryland Reports, Harris and Johnson',
                          'variations': {}}],
             'H. & McH.': [{'cite_type': 'state',
                            'editions': {'H. & McH.': (datetime.date(1770, 1, 1),
                                                       datetime.date(1799, 12, 31))},
                            'mlz_jurisdiction': 'us;md',
                            'name': 'Maryland Reports, Harris and McHenry',
                            'variations': {}}],
             'Hard.': [{'cite_type': 'state',
                        'editions': {'Hard.': (datetime.date(1805, 1, 1),
                                               datetime.date(1808, 12, 31))},
                        'mlz_jurisdiction': 'us;ky',
                        'name': 'Kentucky Reports, Hardin',
                        'variations': {'Hardin': 'Hard.',
                                       'Hardin(Ky.)': 'Hard.',
                                       'Ky.(Hard.)': 'Hard.'}}],
             'Harp.': [{'cite_type': 'state',
                        'editions': {'Harp.': (datetime.date(1823, 1, 1),
                                               datetime.date(1831, 12, 31))},
                        'mlz_jurisdiction': 'us;sc',
                        'name': 'South Carolina Reports, Harper',
                        'variations': {'Harp.L.': 'Harp.',
                                       'Harp.L.(S.C.)': 'Harp.',
                                       'Harper': 'Harp.',
                                       'S.C.L.(Harp.)': 'Harp.'}}],
             'Harp. Eq.': [{'cite_type': 'state',
                            'editions': {'Harp. Eq.': (datetime.date(1824, 1, 1),
                                                       datetime.date(1824, 12, 31))},
                            'mlz_jurisdiction': 'us;sc',
                            'name': "South Carolina Reports, Harper's Equity",
                            'variations': {'Harp.': 'Harp. Eq.',
                                           'Harp.Eq.(S.C.)': 'Harp. Eq.',
                                           'Harper': 'Harp. Eq.',
                                           'S.C.Eq.(Harp.Eq.)': 'Harp. Eq.'}}],
             'Harrington': [{'cite_type': 'state',
                             'editions': {'Harrington': (datetime.date(1832, 1, 1),
                                                         datetime.date(1855, 12, 31))},
                             'mlz_jurisdiction': 'us;de',
                             'name': 'Delaware Reports, Harrington',
                             'variations': {}}],
             'Haw.': [{'cite_type': 'state',
                       'editions': {'Haw.': (datetime.date(1847, 1, 1),
                                             datetime.date.today())},
                       'mlz_jurisdiction': 'us;hi',
                       'name': 'Hawaii Reports',
                       'variations': {'H.': 'Haw.',
                                      'Hawaii': 'Haw.',
                                      'Hawaii Rep.': 'Haw.'}}],
             'Haw. App.': [{'cite_type': 'state',
                            'editions': {'Haw. App.': (datetime.date(1980, 1, 1),
                                                       datetime.date(1994, 12, 31))},
                            'mlz_jurisdiction': 'us;hi',
                            'name': 'Hawaii Appellate Reports',
                            'variations': {'Hawaii App.': 'Haw. App.'}}],
             'Hawks': [{'cite_type': 'state',
                        'editions': {'Hawks': (datetime.date(1820, 1, 1),
                                               datetime.date(1826, 12, 31))},
                        'mlz_jurisdiction': 'us;nc',
                        'name': 'North Carolina Reports, Hawks',
                        'variations': {'Hawks(N.C.)': 'Hawks', 'N.C.(Hawks)': 'Hawks'}}],
             'Hay. & Haz.': [{'cite_type': 'state',
                              'editions': {'Hay. & Haz.': (datetime.date(1841, 1, 1),
                                                           datetime.date(1862, 12, 31))},
                              'mlz_jurisdiction': 'us;dc',
                              'name': 'District of Columbia Reports, Hayward & Hazelton',
                              'variations': {'Hayw.& H.': 'Hay. & Haz.'}}],
             'Hayw.': [{'cite_type': 'state',
                        'editions': {'Hayw.': (datetime.date(1789, 1, 1),
                                               datetime.date(1806, 12, 31))},
                        'mlz_jurisdiction': 'us;nc',
                        'name': 'North Carolina Reports, Haywood',
                        'variations': {'Hay.': 'Hayw.',
                                       'Hayw.N.C.': 'Hayw.',
                                       'N.C.(Hayw.)': 'Hayw.'}},
                       {'cite_type': 'state',
                        'editions': {'Hayw.': (datetime.date(1816, 1, 1),
                                               datetime.date(1818, 12, 31))},
                        'mlz_jurisdiction': 'us;tn',
                        'name': 'Tennessee Reports, Haywood',
                        'variations': {'Hayw.(Tenn.)': 'Hayw.',
                                       'Hayw.Tenn.': 'Hayw.',
                                       'Tenn.(Hayw.)': 'Hayw.'}}],
             'Head': [{'cite_type': 'state',
                       'editions': {'Head': (datetime.date(1858, 1, 1),
                                             datetime.date(1860, 12, 31))},
                       'mlz_jurisdiction': 'us;tn',
                       'name': 'Tennessee Reports, Head',
                       'variations': {'Head(Tenn.)': 'Head', 'Tenn.(Head)': 'Head'}}],
             'Heisk.': [{'cite_type': 'state',
                         'editions': {'Heisk.': (datetime.date(1870, 1, 1),
                                                 datetime.date(1879, 12, 31))},
                         'mlz_jurisdiction': 'us;tn',
                         'name': 'Tennessee Reports, Heiskell',
                         'variations': {'Heisk.(Tenn.)': 'Heisk.',
                                        'Tenn.(Heisk.)': 'Heisk.'}}],
             'Hen. & M.': [{'cite_type': 'state',
                            'editions': {'Hen. & M.': (datetime.date(1806, 1, 1),
                                                       datetime.date(1810, 12, 31))},
                            'mlz_jurisdiction': 'us;va',
                            'name': 'Virginia Reports, Hening & Munford',
                            'variations': {'H.& M.': 'Hen. & M.',
                                           'H.& M.(Va.)': 'Hen. & M.',
                                           'Hen.& Mun.': 'Hen. & M.',
                                           'Va.(Hen.& M.)': 'Hen. & M.'}}],
             'Hill': [{'cite_type': 'state',
                       'editions': {'Hill': (datetime.date(1841, 1, 1),
                                             datetime.date(1844, 12, 31))},
                       'mlz_jurisdiction': 'us;ny',
                       'name': "Hill's New York Reports",
                       'variations': {'H.': 'Hill', 'Hill.N.Y.': 'Hill'}},
                      {'cite_type': 'state',
                       'editions': {'Hill': (datetime.date(1833, 1, 1),
                                             datetime.date(1837, 12, 31))},
                       'mlz_jurisdiction': 'us;sc',
                       'name': 'South Carolina Reports, Hill',
                       'variations': {'Hill Law': 'Hill',
                                      'Hill S.C.': 'Hill',
                                      'S.C.L.(Hill)': 'Hill'}}],
             'Hill & Den.': [{'cite_type': 'state',
                              'editions': {'Hill & Den.': (datetime.date(1842, 1, 1),
                                                           datetime.date(1844, 12, 31))},
                              'mlz_jurisdiction': 'us;ny',
                              'name': 'Hill and Denio Supplement (Lalor)',
                              'variations': {'Hill & D.Supp.': 'Hill & Den.',
                                             'Hill & Den.Supp.': 'Hill & Den.',
                                             'Lalor': 'Hill & Den.',
                                             'Lalor Supp.': 'Hill & Den.'}}],
             'Hill Eq.': [{'cite_type': 'state',
                           'editions': {'Hill Eq.': (datetime.date(1833, 1, 1),
                                                     datetime.date(1837, 12, 31))},
                           'mlz_jurisdiction': 'us;sc',
                           'name': "South Carolina Reports, Hill's Chancery",
                           'variations': {'Hill': 'Hill Eq.',
                                          'Hill Ch.': 'Hill Eq.',
                                          'Hill Eq.(S.C.)': 'Hill Eq.',
                                          'Hill S.C.': 'Hill Eq.',
                                          'S.C.Eq.(Hill Eq.)': 'Hill Eq.'}}],
             'Hoff. Ch.': [{'cite_type': 'state',
                            'editions': {'Hoff. Ch.': (datetime.date(1838, 1, 1),
                                                       datetime.date(1840, 12, 31))},
                            'mlz_jurisdiction': 'us;ny',
                            'name': "Hoffman's Chancery Reports",
                            'variations': {'Hoff.': 'Hoff. Ch.',
                                           'Hoff.Cha.': 'Hoff. Ch.',
                                           'Hoff.N.Y.': 'Hoff. Ch.',
                                           'Hoffm.': 'Hoff. Ch.',
                                           'Hoffm.Ch.(N.Y.)': 'Hoff. Ch.'}}],
             'Hopk. Ch.': [{'cite_type': 'state',
                            'editions': {'Hopk. Ch.': (datetime.date(1823, 1, 1),
                                                       datetime.date(1826, 12, 31))},
                            'mlz_jurisdiction': 'us;ny',
                            'name': "Hopkins' Chancery Reports",
                            'variations': {}}],
             'Houston': [{'cite_type': 'state',
                          'editions': {'Houston': (datetime.date(1855, 1, 1),
                                                   datetime.date(1893, 12, 31))},
                          'mlz_jurisdiction': 'us;de',
                          'name': 'Delaware Reports, Houston',
                          'variations': {}}],
             'How.': [{'cite_type': 'fed',
                       'editions': {'How.': (datetime.date(1843, 1, 1),
                                             datetime.date(1860, 12, 31))},
                       'mlz_jurisdiction': 'us',
                       'name': "Howard's Supreme Court Reports",
                       'variations': {'U.S.(How.)': 'How.'}}],
             'How. Pr.': [{'cite_type': 'state',
                           'editions': {'How. Pr.': (datetime.date(1844, 1, 1),
                                                     datetime.date(1886, 12, 31))},
                           'mlz_jurisdiction': 'us;ny',
                           'name': "Howard's Practice Reports",
                           'variations': {'How.P.R.': 'How. Pr.',
                                          'How.Prac.(N.Y.)': 'How. Pr.',
                                          'N.Y.Spec.Term R.': 'How. Pr.',
                                          'N.Y.Spec.Term Rep.': 'How. Pr.'}}],
             'Howard': [{'cite_type': 'state',
                         'editions': {'Howard': (datetime.date(1834, 1, 1),
                                                 datetime.date(1843, 12, 31))},
                         'mlz_jurisdiction': 'us;ms',
                         'name': 'Mississippi Reports, Howard',
                         'variations': {'How.': 'Howard', 'Miss.(Howard)': 'Howard'}}],
             'Hughes': [{'cite_type': 'state',
                         'editions': {'Hughes': (datetime.date(1785, 1, 1),
                                                 datetime.date(1801, 12, 31))},
                         'mlz_jurisdiction': 'us;ky',
                         'name': 'Kentucky Reports, Hughes',
                         'variations': {'Hugh.': 'Hughes', 'Ky.(Hughes)': 'Hughes'}}],
             'Hum.': [{'cite_type': 'state',
                       'editions': {'Hum.': (datetime.date(1839, 1, 1),
                                             datetime.date(1851, 12, 31))},
                       'mlz_jurisdiction': 'us;tn',
                       'name': 'Tennessee Reports, Humphreys',
                       'variations': {'Humph.': 'Hum.', 'Tenn.(Hum.)': 'Hum.'}}],
             'I.T.R.D. (BNA)': [{'editions': {'I.T.R.D. (BNA)': (datetime.date(1980, 1, 1),
                                                                 datetime.date.today())},
                                 'mlz_jurisdiction': 'us',
                                 'name': 'International Trade Reporter Decisions',
                                 'variations': {}}],
             'Idaho': [{'cite_type': 'state',
                        'editions': {'Idaho': (datetime.date(1982, 1, 1),
                                               datetime.date.today())},
                        'mlz_jurisdiction': 'us;id',
                        'name': 'Idaho Reports',
                        'variations': {'Id.': 'Idaho', 'Ida.': 'Idaho'}}],
             'Ill.': [{'cite_type': 'state',
                       'editions': {'Ill.': (datetime.date(1849, 1, 1),
                                             datetime.date.today())},
                       'mlz_jurisdiction': 'us;il',
                       'name': 'Illinois Reports',
                       'variations': {}}],
             'Ill. App.': [{'cite_type': 'state',
                            'editions': {'Ill. App.': (datetime.date(1877, 1, 1),
                                                       datetime.date.today()),
                                         'Ill. App. 2d': (datetime.date(1877, 1, 1),
                                                          datetime.date.today()),
                                         'Ill. App. 3d': (datetime.date(1877, 1, 1),
                                                          datetime.date.today())},
                            'mlz_jurisdiction': 'us;il',
                            'name': 'Illinois Appellate Court Reports',
                            'variations': {'Ill. App.2d': 'Ill. App. 2d',
                                           'Ill. App.3d': 'Ill. App. 3d',
                                           'Ill.A.': 'Ill. App.',
                                           'Ill.A.2d': 'Ill. App. 2d',
                                           'Ill.A.3d': 'Ill. App. 3d'}}],
             'Ill. Ct. Cl.': [{'cite_type': 'state',
                               'editions': {'Ill. Ct. Cl.': (datetime.date(1889, 1, 1),
                                                             datetime.date.today())},
                               'mlz_jurisdiction': 'us;il',
                               'name': 'Illinois Court of Claims Reports',
                               'variations': {}}],
             'Ill. Dec.': [{'cite_type': 'state',
                            'editions': {'Ill. Dec.': (datetime.date(1976, 1, 1),
                                                       datetime.date.today())},
                            'mlz_jurisdiction': 'us;il',
                            'name': "West's Illinois Decisions",
                            'variations': {'Ill.Dec.': 'Ill. Dec.',
                                           'Ill.Decs.': 'Ill. Dec.'}}],
             'Ind.': [{'cite_type': 'state',
                       'editions': {'Ind.': (datetime.date(1848, 1, 1),
                                             datetime.date(1981, 12, 31))},
                       'mlz_jurisdiction': 'us;in',
                       'name': 'Indiana Reports',
                       'variations': {'Ind.Rep.': 'Ind.'}}],
             'Ind. App.': [{'cite_type': 'state',
                            'editions': {'Ind. App.': (datetime.date(1890, 1, 1),
                                                       datetime.date(1979, 12, 31))},
                            'mlz_jurisdiction': 'us;in',
                            'name': 'Indiana Court of Appeals Reports',
                            'variations': {}}],
             'Indian Terr.': [{'cite_type': 'state',
                               'editions': {'Indian Terr.': (datetime.date(1896, 1, 1),
                                                             datetime.date(1907, 12, 31))},
                               'mlz_jurisdiction': 'us;ok',
                               'name': 'Indian Territory Reports',
                               'variations': {}}],
             'Iowa': [{'cite_type': 'state',
                       'editions': {'Iowa': (datetime.date(1855, 1, 1),
                                             datetime.date(1968, 12, 31))},
                       'mlz_jurisdiction': 'us;ia',
                       'name': 'Iowa Reports',
                       'variations': {}}],
             'Ired.': [{'cite_type': 'state',
                        'editions': {'Ired.': (datetime.date(1840, 1, 1),
                                               datetime.date(1852, 12, 31))},
                        'mlz_jurisdiction': 'us;nc',
                        'name': "North Carolina Reports, Iredell's Law",
                        'variations': {'Ired.L.': 'Ired.',
                                       'Ired.L.(N.C.)': 'Ired.',
                                       'N.C.(Ired.)': 'Ired.'}}],
             'Ired. Eq.': [{'cite_type': 'state',
                            'editions': {'Ired. Eq.': (datetime.date(1840, 1, 1),
                                                       datetime.date(1852, 12, 31))},
                            'mlz_jurisdiction': 'us;nc',
                            'name': "North Carolina Reports, Iredell's Equity",
                            'variations': {'Ired.': 'Ired. Eq.',
                                           'Ired.Eq.(N.C.)': 'Ired. Eq.',
                                           'N.C.(Ired.Eq.)': 'Ired. Eq.'}}],
             'J.J. Marsh.': [{'cite_type': 'state',
                              'editions': {'J.J. Marsh.': (datetime.date(1829, 1, 1),
                                                           datetime.date(1832, 12, 31))},
                              'mlz_jurisdiction': 'us;ky',
                              'name': 'Kentucky Reports, Marshall, J.J.',
                              'variations': {'J.J.Mar.': 'J.J. Marsh.',
                                             'J.J.Marsh.(Ky.)': 'J.J. Marsh.',
                                             'Ky.(J.J.Marsh.)': 'J.J. Marsh.',
                                             'Marsh.': 'J.J. Marsh.',
                                             'Marsh.(Ky.)': 'J.J. Marsh.',
                                             'Marsh.J.J.': 'J.J. Marsh.'}}],
             'Johns.': [{'cite_type': 'state',
                         'editions': {'Johns.': (datetime.date(1806, 1, 1),
                                                 datetime.date(1823, 12, 31))},
                         'mlz_jurisdiction': 'us;ny',
                         'name': "Johnson's Reports",
                         'variations': {'J.': 'Johns.',
                                        'John.': 'Johns.',
                                        'Johns.Ct.Err.': 'Johns.',
                                        'Johns.N.Y.': 'Johns.',
                                        'Johns.Rep.': 'Johns.',
                                        'Johnson': 'Johns.'}}],
             'Johns. Cas.': [{'cite_type': 'state',
                              'editions': {'Johns. Cas.': (datetime.date(1799, 1, 1),
                                                           datetime.date(1803, 12, 31))},
                              'mlz_jurisdiction': 'us;ny',
                              'name': "Johnson's Cases",
                              'variations': {'Johns.Cas.(N.Y.)': 'Johns. Cas.'}}],
             'Johns. Ch.': [{'cite_type': 'state',
                             'editions': {'Johns. Ch.': (datetime.date(1814, 1, 1),
                                                         datetime.date(1823, 12, 31))},
                             'mlz_jurisdiction': 'us;ny',
                             'name': "Johnsons' Chancery Reports",
                             'variations': {'J.Ch.': 'Johns. Ch.',
                                            'Johns.': 'Johns. Ch.',
                                            'Johns.(N.Y.)': 'Johns. Ch.',
                                            'Johns.Ch.(N.Y.)': 'Johns. Ch.',
                                            'Johns.Ch.Cas.': 'Johns. Ch.',
                                            'Johns.Rep.': 'Johns. Ch.',
                                            'Johnson': 'Johns. Ch.'}}],
             'Jones': [{'cite_type': 'state',
                        'editions': {'Jones': (datetime.date(1853, 1, 1),
                                               datetime.date(1862, 12, 31))},
                        'mlz_jurisdiction': 'us;nc',
                        'name': "North Carolina Reports, Jones' Law",
                        'variations': {'Jones L.': 'Jones',
                                       'Jones N.C.': 'Jones',
                                       'N.C.(Jones)': 'Jones'}}],
             'Jones Eq.': [{'cite_type': 'state',
                            'editions': {'Jones Eq.': (datetime.date(1853, 1, 1),
                                                       datetime.date(1863, 12, 31))},
                            'mlz_jurisdiction': 'us;nc',
                            'name': "North Carolina Reports, Jones' Equity",
                            'variations': {'Jones': 'Jones Eq.',
                                           'N.C.(Jones Eq.)': 'Jones Eq.'}}],
             'Kan.': [{'cite_type': 'state',
                       'editions': {'Kan.': (datetime.date(1862, 1, 1),
                                             datetime.date.today())},
                       'mlz_jurisdiction': 'us;ks',
                       'name': 'Kansas Reports',
                       'variations': {'Kans.': 'Kan.'}}],
             'Kan. App.': [{'cite_type': 'state',
                            'editions': {'Kan. App.': (datetime.date(1895, 1, 1),
                                                       datetime.date(1901, 12, 31)),
                                         'Kan. App. 2d': (datetime.date(1977, 1, 1),
                                                          datetime.date.today())},
                            'mlz_jurisdiction': 'us;ks',
                            'name': 'Kansas Court of Appeals Reports',
                            'variations': {'Kan. App.2d': 'Kan. App. 2d',
                                           'Kan.App.': 'Kan. App.',
                                           'Kan.App. 2d': 'Kan. App. 2d',
                                           'Kan.App.2d': 'Kan. App. 2d',
                                           'Kans.App.': 'Kan. App.'}}],
             'Kirby': [{'cite_type': 'state',
                        'editions': {'Kirby': (datetime.date(1785, 1, 1),
                                               datetime.date(1789, 12, 31))},
                        'mlz_jurisdiction': 'us;ct',
                        'name': "Kirby's Connecticut Reports",
                        'variations': {'Kir.': 'Kirby', 'Kirb.': 'Kirby'}}],
             'Ky.': [{'cite_type': 'state',
                      'editions': {'Ky.': (datetime.date(1879, 1, 1),
                                           datetime.date(1951, 12, 31))},
                      'mlz_jurisdiction': 'us;ky',
                      'name': 'Kentucky Reports',
                      'variations': {}}],
             'Ky. App.': [{'cite_type': 'state',
                           'editions': {'Ky. App.': (datetime.date(1994, 1, 1),
                                                     datetime.date(2000, 12, 31))},
                           'mlz_jurisdiction': 'us;ky',
                           'name': 'Kentucky Appellate Reporter',
                           'variations': {}}],
             'Ky. L. Rptr.': [{'cite_type': 'state',
                               'editions': {'Ky. L. Rptr.': (datetime.date(1880, 1, 1),
                                                             datetime.date(1908, 12, 31))},
                               'mlz_jurisdiction': 'us;ky',
                               'name': 'Kentucky Law Reporter',
                               'variations': {'Ken.L.Re.': 'Ky. L. Rptr.',
                                              'Ky.L.R.': 'Ky. L. Rptr.',
                                              'Ky.Law.Rep.': 'Ky. L. Rptr.'}}],
             'Ky. L. Summ.': [{'cite_type': 'state',
                               'editions': {'Ky. L. Summ.': (datetime.date(1966, 1, 1),
                                                             datetime.date.today())},
                               'mlz_jurisdiction': 'us;ky',
                               'name': 'Kentucky Law Summary',
                               'variations': {}}],
             'Ky. Op.': [{'cite_type': 'state',
                          'editions': {'Ky. Op.': (datetime.date(1864, 1, 1),
                                                   datetime.date(1886, 12, 31))},
                          'mlz_jurisdiction': 'us;ky',
                          'name': 'Kentucky Opinions',
                          'variations': {'Ken.Opin.': 'Ky. Op.'}}],
             'L. Ed.': [{'cite_type': 'fed',
                         'editions': {'L. Ed.': (datetime.date(1790, 1, 1),
                                                 datetime.date(1956, 12, 31)),
                                      'L. Ed. 2d': (datetime.date(1956, 1, 1),
                                                    datetime.date.today())},
                         'mlz_jurisdiction': 'us',
                         'name': "Lawyer's Edition",
                         'variations': {'L Ed': 'L. Ed.',
                                        'L Ed 2d': 'L. Ed. 2d',
                                        'L. Ed.2d': 'L. Ed. 2d',
                                        'L.E.': 'L. Ed.',
                                        'L.E.2d': 'L. Ed. 2d',
                                        'L.Ed.': 'L. Ed.',
                                        'L.Ed. 2d': 'L. Ed. 2d',
                                        'L.Ed.(U.S.)': 'L. Ed.',
                                        'L.Ed.2d': 'L. Ed. 2d',
                                        'LAW ED': 'L. Ed.',
                                        'Law.Ed.': 'L. Ed.',
                                        'U.S.L.Ed.': 'L. Ed.',
                                        'U.S.L.Ed.2d': 'L. Ed. 2d',
                                        'U.S.Law.Ed.': 'L. Ed.'}}],
             'LA': [{'cite_type': 'neutral',
                     'editions': {'LA': (datetime.date(1750, 1, 1),
                                         datetime.date.today())},
                     'mlz_jurisdiction': 'us;la',
                     'name': 'Louisiana Neutral Citation',
                     'variations': {}}],
             'La.': [{'cite_type': 'state',
                      'editions': {'La.': (datetime.date(1830, 1, 1),
                                           datetime.date(1972, 12, 31))},
                      'mlz_jurisdiction': 'us;la',
                      'name': 'Louisiana Reports',
                      'variations': {}}],
             'La. Ann.': [{'cite_type': 'state',
                           'editions': {'La. Ann.': (datetime.date(1846, 1, 1),
                                                     datetime.date(1900, 12, 31))},
                           'mlz_jurisdiction': 'us;la',
                           'name': 'Louisiana Annual Reports',
                           'variations': {}}],
             'La. App.': [{'cite_type': 'state',
                           'editions': {'La. App.': (datetime.date(1924, 1, 1),
                                                     datetime.date(1932, 12, 31))},
                           'mlz_jurisdiction': 'us;la',
                           'name': 'Louisiana Court of Appeals Reports',
                           'variations': {'La.A.': 'La. App.'}}],
             'Lans.': [{'cite_type': 'state',
                        'editions': {'Lans.': (datetime.date(1869, 1, 1),
                                               datetime.date(1873, 12, 31))},
                        'mlz_jurisdiction': 'us;ny',
                        'name': "Lansing's Reports",
                        'variations': {}}],
             'Lans. Ch.': [{'cite_type': 'state',
                            'editions': {'Lans. Ch.': (datetime.date(1824, 1, 1),
                                                       datetime.date(1826, 12, 31))},
                            'mlz_jurisdiction': 'us;ny',
                            'name': "Lansing's Chancery Reports",
                            'variations': {'L.': 'Lans. Ch.', 'Lans.': 'Lans. Ch.'}}],
             'Leigh': [{'cite_type': 'state',
                        'editions': {'Leigh': (datetime.date(1829, 1, 1),
                                               datetime.date(1842, 12, 31))},
                        'mlz_jurisdiction': 'us;va',
                        'name': 'Virginia Reports, Leigh',
                        'variations': {'Leigh (Va.)': 'Leigh', 'Va.(Leigh)': 'Leigh'}}],
             'Litt.': [{'cite_type': 'state',
                        'editions': {'Litt.': (datetime.date(1822, 1, 1),
                                               datetime.date(1824, 12, 31))},
                        'mlz_jurisdiction': 'us;ky',
                        'name': 'Kentucky Reports, Littell',
                        'variations': {'Ky.(Litt.)': 'Litt.',
                                       'Lit.': 'Litt.',
                                       'Litt.(Ky.)': 'Litt.',
                                       'Littell': 'Litt.'}}],
             'Litt. Sel. Cas.': [{'cite_type': 'state',
                                  'editions': {'Litt. Sel. Cas.': (datetime.date(1795, 1, 1),
                                                                   datetime.date(1821, 12, 31))},
                                  'mlz_jurisdiction': 'us;ky',
                                  'name': "Kentucky Reports, Littell's Selected Cases",
                                  'variations': {'Ky.(Lit.Sel.Cas.)': 'Litt. Sel. Cas.',
                                                 'Lit.Sel.Ca.': 'Litt. Sel. Cas.'}}],
             'Lock. Rev. Cas.': [{'cite_type': 'state',
                                  'editions': {'Lock. Rev. Cas.': (datetime.date(1799, 1, 1),
                                                                   datetime.date(1847, 12, 31))},
                                  'mlz_jurisdiction': 'us;ny',
                                  'name': "Lockwood's Reversed Cases",
                                  'variations': {}}],
             'M.J.': [{'cite_type': 'fed',
                       'editions': {'M.J.': (datetime.date(1975, 1, 1),
                                             datetime.date.today())},
                       'mlz_jurisdiction': 'us',
                       'name': 'Military Justice Reporter',
                       'variations': {'M. J.': 'M.J.'}}],
             'ME': [{'cite_type': 'neutral',
                     'editions': {'ME': (datetime.date(1750, 1, 1),
                                         datetime.date.today())},
                     'mlz_jurisdiction': 'us;me',
                     'name': 'Maine Neutral Citation',
                     'variations': {}}],
             'MS': [{'cite_type': 'neutral',
                     'editions': {'MS': (datetime.date(1750, 1, 1),
                                         datetime.date.today())},
                     'mlz_jurisdiction': 'us;ms',
                     'name': 'Mississippi Neutral Citation',
                     'variations': {}}],
             'MT': [{'cite_type': 'neutral',
                     'editions': {'MT': (datetime.date(1750, 1, 1),
                                         datetime.date.today())},
                     'mlz_jurisdiction': 'us;mt',
                     'name': 'Montana Neutral Citation',
                     'variations': {}}],
             'MacArth.': [{'cite_type': 'state',
                           'editions': {'MacArth.': (datetime.date(1873, 1, 1),
                                                     datetime.date(1879, 12, 31))},
                           'mlz_jurisdiction': 'us;dc',
                           'name': 'District of Columbia Reports, MacArthur',
                           'variations': {'D.C.(MacArth.)': 'MacArth.',
                                          'MacAr.': 'MacArth.',
                                          'MacArthur': 'MacArth.'}}],
             'MacArth. & M.': [{'cite_type': 'state',
                                'editions': {'MacArth. & M.': (datetime.date(1879, 1, 1),
                                                               datetime.date(1880, 12, 31))},
                                'mlz_jurisdiction': 'us;dc',
                                'name': 'District of Columbia Reports, MacArthur and Mackey',
                                'variations': {'D.C.(MacArth.& M.)': 'MacArth. & M.',
                                               'MacAr.& M.': 'MacArth. & M.',
                                               'MacAr.& Mackey': 'MacArth. & M.',
                                               'MacArth.& M.(Dist.Col.)': 'MacArth. & M.',
                                               'MacArthur & M.': 'MacArth. & M.'}}],
             'Mackey': [{'cite_type': 'state',
                         'editions': {'Mackey': (datetime.date(1863, 1, 1),
                                                 datetime.date(1892, 12, 31))},
                         'mlz_jurisdiction': 'us;dc',
                         'name': 'District of Columbia Reports, Mackey',
                         'variations': {'D.C.(Mackey)': 'Mackey'}}],
             'Mart.': [{'cite_type': 'state',
                        'editions': {'Mart.': (datetime.date(1809, 1, 1),
                                               datetime.date(1830, 12, 31))},
                        'mlz_jurisdiction': 'us;la',
                        'name': 'Louisiana Reports, Martin',
                        'variations': {}},
                       {'cite_type': 'state',
                        'editions': {'Mart.': (datetime.date(1778, 1, 1),
                                               datetime.date(1797, 12, 31))},
                        'mlz_jurisdiction': 'us;nc',
                        'name': 'North Carolina Reports, Martin',
                        'variations': {'Mart.Dec.': 'Mart.',
                                       'Mart.N.C.': 'Mart.',
                                       'Martin': 'Mart.',
                                       'N.C.(Mart.)': 'Mart.'}}],
             'Mart. & Yer.': [{'cite_type': 'state',
                               'editions': {'Mart. & Yer.': (datetime.date(1825, 1, 1),
                                                             datetime.date(1828, 12, 31))},
                               'mlz_jurisdiction': 'us;tn',
                               'name': 'Tennessee Reports, Martin & Yerger',
                               'variations': {'M.& Y.': 'Mart. & Yer.',
                                              'M.& Y.R.': 'Mart. & Yer.',
                                              'Mart.& Y.': 'Mart. & Yer.',
                                              'Mart.& Y.(Tenn.)': 'Mart. & Yer.',
                                              'Mart.& Yerg.': 'Mart. & Yer.'}}],
             'Marvel': [{'cite_type': 'state',
                         'editions': {'Marvel': (datetime.date(1893, 1, 1),
                                                 datetime.date(1897, 12, 31))},
                         'mlz_jurisdiction': 'us;de',
                         'name': 'Delaware Reports, Marvel',
                         'variations': {}}],
             'Mass.': [{'cite_type': 'state',
                        'editions': {'Mass.': (datetime.date(1867, 1, 1),
                                               datetime.date.today())},
                        'mlz_jurisdiction': 'us;ma',
                        'name': 'Massachusetts Reports',
                        'variations': {'Ma.': 'Mass.', 'Mas.': 'Mass.'}}],
             'Mass. App. Ct.': [{'cite_type': 'state',
                                 'editions': {'Mass. App. Ct.': (datetime.date(1972, 1, 1),
                                                                 datetime.date.today())},
                                 'mlz_jurisdiction': 'us;ma',
                                 'name': 'Massachusetts Appeals Court Reports',
                                 'variations': {'Ma.A.': 'Mass. App. Ct.'}}],
             'Mass. App. Dec.': [{'cite_type': 'state',
                                  'editions': {'Mass. App. Dec.': (datetime.date(1941, 1, 1),
                                                                   datetime.date(1977, 12, 31))},
                                  'mlz_jurisdiction': 'us;ma',
                                  'name': 'Massachusetts Appellate Decisions',
                                  'variations': {}}],
             'Mass. App. Div.': [{'cite_type': 'state',
                                  'editions': {'Mass. App. Div.': (datetime.date(1936, 1, 1),
                                                                   datetime.date.today())},
                                  'mlz_jurisdiction': 'us;ma',
                                  'name': 'Reports of Massachusetts Appellate Division',
                                  'variations': {}}],
             'Mass. Supp.': [{'cite_type': 'state',
                              'editions': {'Mass. Supp.': (datetime.date(1980, 1, 1),
                                                           datetime.date(1983, 12, 31))},
                              'mlz_jurisdiction': 'us;ma',
                              'name': 'Massachusetts Reports Supplement',
                              'variations': {}}],
             'McCahon': [{'cite_type': 'state',
                          'editions': {'McCahon': (datetime.date(1858, 1, 1),
                                                   datetime.date(1868, 12, 31))},
                          'mlz_jurisdiction': 'us;ks',
                          'name': 'Kansas Reports, McCahon',
                          'variations': {'McCah.': 'McCahon'}}],
             'McCord': [{'cite_type': 'state',
                         'editions': {'McCord': (datetime.date(1821, 1, 1),
                                                 datetime.date(1828, 12, 31))},
                         'mlz_jurisdiction': 'us;sc',
                         'name': 'South Carolina Reports, McCord',
                         'variations': {'S.C.L.(McCord)': 'McCord'}}],
             'McCord Eq.': [{'cite_type': 'state',
                             'editions': {'McCord Eq.': (datetime.date(1825, 1, 1),
                                                         datetime.date(1827, 12, 31))},
                             'mlz_jurisdiction': 'us;sc',
                             'name': "South Carolina Reports, McCord's Chancery",
                             'variations': {'McCord Ch.': 'McCord Eq.',
                                            'S.C.L.(McCord Eq.)': 'McCord Eq.'}}],
             'McGl.': [{'cite_type': 'state',
                        'editions': {'McGl.': (datetime.date(1881, 1, 1),
                                               datetime.date(1884, 12, 31))},
                        'mlz_jurisdiction': 'us;la',
                        'name': 'Louisiana Court of Appeals Reports, McGloin',
                        'variations': {'McGloin': 'McGl.'}}],
             'McMul.': [{'cite_type': 'state',
                         'editions': {'McMul.': (datetime.date(1840, 1, 1),
                                                 datetime.date(1842, 12, 31))},
                         'mlz_jurisdiction': 'us;sc',
                         'name': 'South Carolina Reports, McMullen',
                         'variations': {'McMul.L.(S.C.)': 'McMul.',
                                        'S.C.L.(McMul.)': 'McMul.'}}],
             'McMul. Eq.': [{'cite_type': 'state',
                             'editions': {'McMul. Eq.': (datetime.date(1840, 1, 1),
                                                         datetime.date(1842, 12, 31))},
                             'mlz_jurisdiction': 'us;sc',
                             'name': "South Carolina Reports, McMullen's Equity",
                             'variations': {'McMul.Eq.(S.C.)': 'McMul. Eq.',
                                            'S.C.L.(McMullan Eq.)': 'McMul. Eq.'}}],
             'Md.': [{'cite_type': 'state',
                      'editions': {'Md.': (datetime.date(1851, 1, 1),
                                           datetime.date.today())},
                      'mlz_jurisdiction': 'us;md',
                      'name': 'Maryland Reports',
                      'variations': {'Maryland': 'Md.'}}],
             'Md. App.': [{'cite_type': 'state',
                           'editions': {'Md. App.': (datetime.date(1967, 1, 1),
                                                     datetime.date.today())},
                           'mlz_jurisdiction': 'us;md',
                           'name': 'Maryland Appellate Reports',
                           'variations': {}}],
             'Me.': [{'cite_type': 'state',
                      'editions': {'Me.': (datetime.date(1820, 1, 1),
                                           datetime.date(1965, 12, 31))},
                      'mlz_jurisdiction': 'us;me',
                      'name': 'Maine Reports',
                      'variations': {'Mai.': 'Me.', 'Maine': 'Me.'}}],
             'Meigs': [{'cite_type': 'state',
                        'editions': {'Meigs': (datetime.date(1838, 1, 1),
                                               datetime.date(1839, 12, 31))},
                        'mlz_jurisdiction': 'us;tn',
                        'name': 'Tennessee Reports, Meigs',
                        'variations': {'Tenn.(Meigs)': 'Meigs'}}],
             'Met.': [{'cite_type': 'state',
                       'editions': {'Met.': (datetime.date(1858, 1, 1),
                                             datetime.date(1863, 12, 31))},
                       'mlz_jurisdiction': 'us;ky',
                       'name': 'Kentucky Reports, Metcalf',
                       'variations': {'Ky.(Met.)': 'Met.',
                                      'Metc.': 'Met.',
                                      'Metc.Ky.': 'Met.'}},
                      {'cite_type': 'state',
                       'editions': {'Met.': (datetime.date(1840, 1, 1),
                                             datetime.date(1847, 12, 31))},
                       'mlz_jurisdiction': 'us;ma',
                       'name': 'Massachusetts Reports, Metcalf',
                       'variations': {'Mass.(Met.)': 'Met.',
                                      'Metc.': 'Met.',
                                      'Metc.Mass.': 'Met.'}}],
             'Mich.': [{'cite_type': 'state',
                        'editions': {'Mich.': (datetime.date(1847, 1, 1),
                                               datetime.date.today())},
                        'mlz_jurisdiction': 'us;mi',
                        'name': 'Michigan Reports',
                        'variations': {'Mich.': 'Mich.'}}],
             'Mich. App.': [{'cite_type': 'state',
                             'editions': {'Mich. App.': (datetime.date(1965, 1, 1),
                                                         datetime.date.today())},
                             'mlz_jurisdiction': 'us;mi',
                             'name': 'Michigan Appeals Reports',
                             'variations': {}}],
             'Mich. Ct. Cl.': [{'cite_type': 'state',
                                'editions': {'Mich. Ct. Cl.': (datetime.date(1938, 1, 1),
                                                               datetime.date(1942, 12, 31))},
                                'mlz_jurisdiction': 'us;mi',
                                'name': 'Michigan Court of Claims Reports',
                                'variations': {}}],
             'Mill': [{'cite_type': 'state',
                       'editions': {'Mill': (datetime.date(1817, 1, 1),
                                             datetime.date(1818, 12, 31))},
                       'mlz_jurisdiction': 'us;sc',
                       'name': 'South Carolina Reports, Mill (Constitutional)',
                       'variations': {'Const.': 'Mill',
                                      'Const.S.C.': 'Mill',
                                      'Mill Const.': 'Mill',
                                      'Mill Const.(S.C.)': 'Mill',
                                      'S.C.L.(Mill)': 'Mill'}}],
             'Minn.': [{'cite_type': 'state',
                        'editions': {'Minn.': (datetime.date(1851, 1, 1),
                                               datetime.date(1977, 12, 31))},
                        'mlz_jurisdiction': 'us;mn',
                        'name': 'Minnesota Reports',
                        'variations': {'Min.': 'Minn.'}}],
             'Minor': [{'cite_type': 'state',
                        'editions': {'Minor': (datetime.date(1820, 1, 1),
                                               datetime.date(1826, 1, 1))},
                        'mlz_jurisdiction': 'us;al',
                        'name': "Minor's Alabama Reports",
                        'variations': {'Min.': 'Minor',
                                       'Minor (Ala.)': 'Minor'}}],
             'Misc.': [{'cite_type': 'state',
                        'editions': {'Misc.': (datetime.date(1892, 1, 1),
                                               datetime.date(1955, 12, 31)),
                                     'Misc. 2d': (datetime.date(1955, 1, 1),
                                                  datetime.date(2004, 12, 31)),
                                     'Misc. 3d': (datetime.date(2004, 1, 1),
                                                  datetime.date.today())},
                        'mlz_jurisdiction': 'us;ny',
                        'name': 'New York Miscellaneous Reports',
                        'variations': {'Misc 2d': 'Misc. 2d',
                                       'Misc 3d': 'Misc. 3d',
                                       'Misc.2d': 'Misc. 2d',
                                       'Misc.3d': 'Misc. 3d'}}],
             'Miss.': [{'cite_type': 'state',
                        'editions': {'Miss.': (datetime.date(1851, 1, 1),
                                               datetime.date(1966, 12, 31))},
                        'mlz_jurisdiction': 'us;ms',
                        'name': 'Mississippi Reports',
                        'variations': {'Mis.': 'Miss.'}}],
             'Mo.': [{'cite_type': 'state',
                      'editions': {'Mo.': (datetime.date(1821, 1, 1),
                                           datetime.date(1956, 12, 31))},
                      'mlz_jurisdiction': 'us;mo',
                      'name': 'Missouri Reports',
                      'variations': {}}],
             'Mo. App.': [{'cite_type': 'state',
                           'editions': {'Mo. App.': (datetime.date(1876, 1, 1),
                                                     datetime.date(1954, 12, 31))},
                           'mlz_jurisdiction': 'us;mo',
                           'name': 'Missouri Appeals Reports',
                           'variations': {'Mo.App.Rep.': 'Mo. App.'}}],
             'Monag.': [{'cite_type': 'state',
                         'editions': {'Monag.': (datetime.date(1888, 1, 1),
                                                 datetime.date(1890, 12, 31))},
                         'mlz_jurisdiction': 'us;pa',
                         'name': 'Pennsylvania State Reports, Monaghan',
                         'variations': {'Mon.': 'Monag.',
                                        'Mona.': 'Monag.',
                                        'Monaghan': 'Monag.',
                                        'Monaghan(Pa.)': 'Monag.'}}],
             'Mont.': [{'cite_type': 'state',
                        'editions': {'Mont.': (datetime.date(1868, 1, 1),
                                               datetime.date.today())},
                        'mlz_jurisdiction': 'us;mt',
                        'name': 'Montana Reports',
                        'variations': {'Mont.': 'Mont.'}}],
             'Morris': [{'cite_type': 'state',
                         'editions': {'Morris': (datetime.date(1839, 1, 1),
                                                 datetime.date(1846, 12, 31))},
                         'mlz_jurisdiction': 'us;ia',
                         'name': 'Iowa Reports, Morris',
                         'variations': {'Mor.Ia.': 'Morris', 'Morr.': 'Morris'}}],
             'Munf.': [{'cite_type': 'state',
                        'editions': {'Monf.': (datetime.date(1810, 1, 1),
                                               datetime.date(1820, 12, 31))},
                        'mlz_jurisdiction': 'us;va',
                        'name': 'Virginia Reports, Munford',
                        'variations': {}}],
             'Mur.': [{'cite_type': 'state',
                       'editions': {'Mur.': (datetime.date(1804, 1, 1),
                                             datetime.date(1819, 12, 31))},
                       'mlz_jurisdiction': 'us;nc',
                       'name': 'North Carolina Reports, Murphey',
                       'variations': {'Murph.': 'Mur.',
                                      'Murph.(N.C.)': 'Mur.',
                                      'N.C.(Mur.)': 'Mur.'}}],
             'N. Chip.': [{'cite_type': 'state',
                           'editions': {'N. Chip.': (datetime.date(1789, 1, 1),
                                                     datetime.date(1791, 12, 31))},
                           'mlz_jurisdiction': 'us;vt',
                           'name': 'Vermont Reports, Chipman, N.',
                           'variations': {'Chip.N.': 'N. Chip.',
                                          'N.Chip.(Vt.)': 'N. Chip.',
                                          'N.Chipm.': 'N. Chip.'}}],
             'N. Mar. I.': [{'cite_type': 'state',
                             'editions': {'N. Mar. I.': (datetime.date(1989, 1, 1),
                                                         datetime.date.today())},
                             'mlz_jurisdiction': 'us;mp',
                             'name': 'Northern Mariana Islands Reporter',
                             'variations': {}}],
             'N. Mar. I. Commw. Rptr.': [{'cite_type': 'state',
                                          'editions': {'N. Mar. I. Commw. Rptr.': (datetime.date(1979, 1, 1),
                                                                                   datetime.date.today())},
                                          'mlz_jurisdiction': 'us;mp',
                                          'name': 'Northern Mariana Islands Commonwealth Reporter',
                                          'variations': {}}],
             'N.C.': [{'cite_type': 'state',
                       'editions': {'N.C.': (datetime.date(1868, 1, 1),
                                             datetime.date.today())},
                       'mlz_jurisdiction': 'us;nc',
                       'name': 'North Carolina Reports',
                       'variations': {}}],
             'N.C. App.': [{'cite_type': 'state',
                            'editions': {'N.C. App.': (datetime.date(1968, 1, 1),
                                                       datetime.date.today())},
                            'mlz_jurisdiction': 'us;nc',
                            'name': 'North Carolina Court of Appeals Reports',
                            'variations': {}}],
             'N.D.': [{'cite_type': 'state',
                       'editions': {'N.D.': (datetime.date(1890, 1, 1),
                                             datetime.date(1953, 12, 31))},
                       'mlz_jurisdiction': 'us;nd',
                       'name': 'North Dakota Reports',
                       'variations': {}}],
             'N.E.': [{'cite_type': 'state_regional',
                       'editions': {'N.E.': (datetime.date(1884, 1, 1),
                                             datetime.date(1936, 12, 31)),
                                    'N.E.2d': (datetime.date(1936, 1, 1),
                                               datetime.date.today())},
                       'mlz_jurisdiction': 'us',
                       'name': 'North Eastern Reporter',
                       'variations': {'N. E.': 'N.E.',
                                      'N. E. 2d': 'N.E.2d',
                                      'N. E.2d': 'N.E.2d',
                                      'N.E. 2d': 'N.E.2d',
                                      'N.E.Rep.': 'N.E.',
                                      'NE': 'N.E.',
                                      'NE 2d': 'N.E.2d',
                                      'No.East Rep.': 'N.E.'}}],
             'N.H.': [{'cite_type': 'state',
                       'editions': {'N.H.': (datetime.date(1816, 1, 1),
                                             datetime.date.today())},
                       'mlz_jurisdiction': 'us;nh',
                       'name': 'New Hampshire Reports',
                       'variations': {'N.H.R.': 'N.H.'}}],
             'N.J.': [{'cite_type': 'state',
                       'editions': {'N.J.': (datetime.date(1948, 1, 1),
                                             datetime.date.today())},
                       'mlz_jurisdiction': 'us;nj',
                       'name': 'New Jersey Reports',
                       'variations': {}}],
             'N.J. Admin.': [{'cite_type': 'state',
                              'editions': {'N.J. Admin.': (datetime.date(1982, 1, 1),
                                                           datetime.date.today()),
                                           'N.J. Admin. 2d': (datetime.date(1982, 1, 1),
                                                              datetime.date.today())},
                              'mlz_jurisdiction': 'us;nj',
                              'name': 'New Jersey Administrative Reports',
                              'variations': {}}],
             'N.J. Eq.': [{'cite_type': 'state',
                           'editions': {'N.J. Eq.': (datetime.date(1830, 1, 1),
                                                     datetime.date(1948, 12, 31))},
                           'mlz_jurisdiction': 'us;nj',
                           'name': 'New Jersey Equity Reports',
                           'variations': {}}],
             'N.J. Misc.': [{'cite_type': 'state',
                             'editions': {'N.J. Misc.': (datetime.date(1923, 1, 1),
                                                         datetime.date(1949, 12, 31))},
                             'mlz_jurisdiction': 'us;nj',
                             'name': 'New Jersey Miscellaneous Reports',
                             'variations': {'N.J.M.': 'N.J. Misc.', 'NJM': 'N.J. Misc.'}}],
             'N.J. Super.': [{'cite_type': 'state',
                              'editions': {'N.J. Super.': (datetime.date(1948, 1, 1),
                                                           datetime.date.today())},
                              'mlz_jurisdiction': 'us;nj',
                              'name': 'New Jersey Superior Court Reports',
                              'variations': {'N.J.S.': 'N.J. Super.'}}],
             'N.J. Tax': [{'cite_type': 'state',
                           'editions': {'N.J. Tax.': (datetime.date(1979, 1, 1),
                                                      datetime.date.today())},
                           'mlz_jurisdiction': 'us;nj',
                           'name': 'New Jersey Tax Court',
                           'variations': {}}],
             'N.J.L.': [{'cite_type': 'state',
                         'editions': {'N.J.L.': (datetime.date(1790, 1, 1),
                                                 datetime.date(1948, 12, 31))},
                         'mlz_jurisdiction': 'us;nj',
                         'name': 'New Jersey Law Reports',
                         'variations': {'N.J.Law': 'N.J.L.'}}],
             'N.M.': [{'cite_type': 'state',
                       'editions': {'N.M.': (datetime.date(1890, 1, 1),
                                             datetime.date.today())},
                       'mlz_jurisdiction': 'us;nm',
                       'name': 'New Mexico Reports',
                       'variations': {}}],
             'N.W.': [{'cite_type': 'state_regional',
                       'editions': {'N.W.': (datetime.date(1880, 1, 1),
                                             datetime.date(1942, 12, 31)),
                                    'N.W.2d': (datetime.date(1942, 1, 1),
                                               datetime.date.today())},
                       'mlz_jurisdiction': 'us',
                       'name': 'North Western Reporter',
                       'variations': {'N. W.': 'N.W.',
                                      'N. W. 2d': 'N.W.2d',
                                      'N. W.2d': 'N.W.2d',
                                      'N.W. 2d': 'N.W.2d',
                                      'NW': 'N.W.',
                                      'NW 2d': 'N.W.2d',
                                      'No.West Rep.': 'N.W.',
                                      'Northw.Rep.': 'N.W.'}}],
             'N.Y.': [{'cite_type': 'state',
                       'editions': {'N.Y.': (datetime.date(1847, 1, 1),
                                             datetime.date(1956, 12, 31)),
                                    'N.Y.2d': (datetime.date(1956, 1, 1),
                                               datetime.date(2004, 1, 1)),
                                    'N.Y.3d': (datetime.date(2004, 1, 1),
                                               datetime.date.today())},
                       'mlz_jurisdiction': 'us;ny',
                       'name': 'New York Reports',
                       'variations': {'N. Y.': 'N.Y.',
                                      'N.Y. 2d': 'N.Y.2d',
                                      'N.Y. 3d': 'N.Y.3d',
                                      'NY 2d': 'N.Y.2d',
                                      'NY 3d': 'N.Y.3d'}}],
             'N.Y. Ch. Ann.': [{'cite_type': 'state',
                                'editions': {'N.Y. Ch. Ann.': (datetime.date(1814, 1, 1),
                                                               datetime.date(1847, 12, 31))},
                                'mlz_jurisdiction': 'us;ny',
                                'name': 'New York Chancery Reports Annotated',
                                'variations': {'N.Y.Ch.R.Ann.': 'N.Y. Ch. Ann.'}}],
             'N.Y. Sup. Ct.': [{'cite_type': 'state',
                                'editions': {'N.Y. Sup. Ct.': (datetime.date(1873, 1, 1),
                                                               datetime.date(1896, 12, 31))},
                                'mlz_jurisdiction': 'us;ny',
                                'name': 'Supreme Court Reports',
                                'variations': {'N.Y.Supr.Ct.': 'N.Y. Sup. Ct.',
                                               'N.Y.Suprm.Ct.': 'N.Y. Sup. Ct.'}}],
             'N.Y.S.': [{'cite_type': 'state',
                         'editions': {'N.Y.S.': (datetime.date(1888, 1, 1),
                                                 datetime.date(1937, 12, 31)),
                                      'N.Y.S.2d': (datetime.date(1938, 1, 1),
                                                   datetime.date.today())},
                         'mlz_jurisdiction': 'us;ny',
                         'name': 'New York Supplement',
                         'variations': {'N.Y.S. 2d': 'N.Y.S.2d',
                                        'N.Y.S. 3d': 'N.Y.S.3d',
                                        'NYS': 'N.Y.S.',
                                        'NYS 2d': 'N.Y.S.2d',
                                        'NYS 3d': 'N.Y.S.3d',
                                        'New York Supp.': 'N.Y.S.'}}],
             'ND': [{'cite_type': 'neutral',
                     'editions': {'ND': (datetime.date(1750, 1, 1),
                                         datetime.date.today())},
                     'mlz_jurisdiction': 'us;nd',
                     'name': 'North Dakota Neutral Citation',
                     'variations': {}}],
             'ND App': [{'cite_type': 'neutral',
                         'editions': {'ND App': (datetime.date(1750, 1, 1),
                                                 datetime.date.today())},
                         'mlz_jurisdiction': 'us;nd',
                         'name': 'North Dakota Neutral Citation, Court of Appeals',
                         'variations': {}}],
             'NM': [{'cite_type': 'neutral',
                     'editions': {'NM': (datetime.date(1750, 1, 1),
                                         datetime.date.today())},
                     'mlz_jurisdiction': 'us;nm',
                     'name': 'New Mexico Neutral Citation',
                     'variations': {}}],
             'NMCA': [{'cite_type': 'neutral',
                       'editions': {'NMCA': (datetime.date(1750, 1, 1),
                                             datetime.date.today())},
                       'mlz_jurisdiction': 'us;nm',
                       'name': 'New Mexico Neutral Citation (Court of Appeals)',
                       'variations': {}}],
             'NMCERT': [{'cite_type': 'neutral',
                         'editions': {'NMCERT': (datetime.date(1750, 1, 1),
                                                 datetime.date.today())},
                         'mlz_jurisdiction': 'us;nm',
                         'name': 'New Mexico Neutral Citation',
                         'variations': {}}],
             'NMSC': [{'cite_type': 'neutral',
                       'editions': {'NMSC': (datetime.date(1750, 1, 1),
                                             datetime.date.today())},
                       'mlz_jurisdiction': 'us;nm',
                       'name': 'New Mexico Neutral Citation (Supreme Court)',
                       'variations': {}}],
             'NY Slip Op': [{'cite_type': 'state',
                             'editions': {'NY Slip Op': (datetime.date(1750, 1, 1),
                                                         datetime.date.today())},
                             'mlz_jurisdiction': 'us;ny',
                             'name': 'New York Slip Opinion',
                             'variations': {}}],
             'Navajo Rptr.': [{'cite_type': 'fed',
                               'editions': {'Navajo Rptr.': (datetime.date(1969, 1, 1),
                                                             datetime.date.today())},
                               'mlz_jurisdiction': 'us',
                               'name': 'Navajo Reporter',
                               'variations': {}}],
             'Neb.': [{'cite_type': 'state',
                       'editions': {'Neb.': (datetime.date(1860, 1, 1),
                                             datetime.date.today())},
                       'mlz_jurisdiction': 'us;ne',
                       'name': 'Nebraska Reports',
                       'variations': {}}],
             'Neb. Ct. App.': [{'cite_type': 'state',
                                'editions': {'Neb. Ct. App.': (datetime.date(1922, 1, 1),
                                                               datetime.date.today())},
                                'mlz_jurisdiction': 'us;ne',
                                'name': 'Nebraska Court of Appeals Reports',
                                'variations': {'Neb. App.': 'Neb. Ct. App.',
                                               'Neb.App.R.': 'Neb. Ct. App.'}}],
             'Nev.': [{'cite_type': 'state',
                       'editions': {'Nev.': (datetime.date(1865, 1, 1),
                                             datetime.date.today())},
                       'mlz_jurisdiction': 'us;nv',
                       'name': 'Nevada Reports',
                       'variations': {}}],
             'Nev. Adv. Op. No.': [{'cite_type': 'state',
                                    'editions': {'Nev. Adv. Op. No.': (datetime.date(1750, 1, 1),
                                                                       datetime.date.today())},
                                    'mlz_jurisdiction': 'us;nv',
                                    'name': 'Nevada Advanced Opinion',
                                    'variations': {}}],
             'Nott & McC.': [{'cite_type': 'state',
                              'editions': {'Nott & McC.': (datetime.date(1817, 1, 1),
                                                           datetime.date(1820, 12, 31))},
                              'mlz_jurisdiction': 'us;sc',
                              'name': 'South Carolina Reports, Nott and McCord',
                              'variations': {'N.& Mc.': 'Nott & McC.',
                                             "Nott & M'C.(S.C.)": 'Nott & McC.',
                                             'Nott & McC.': 'Nott & McC.',
                                             'S.C.L.(Nott & McC.)': 'Nott & McC.'}}],
             'OH': [{'cite_type': 'neutral',
                     'editions': {'OH': (datetime.date(1750, 1, 1),
                                         datetime.date.today())},
                     'mlz_jurisdiction': 'us;oh',
                     'name': 'Ohio Neutral Citation',
                     'variations': {'-Ohio-': 'OH'}}],
             'OK': [{'cite_type': 'neutral',
                     'editions': {'OK': (datetime.date(1750, 1, 1),
                                         datetime.date.today())},
                     'mlz_jurisdiction': 'us;ok',
                     'name': 'Oklahoma Neutral Citation',
                     'variations': {}}],
             'OK CIV APP': [{'cite_type': 'neutral',
                             'editions': {'OKCIVAPP': (datetime.date(1750, 1, 1),
                                                       datetime.date.today())},
                             'mlz_jurisdiction': 'us;ok',
                             'name': 'Oklahoma Neutral Citation (Civic Appeals)',
                             'variations': {}}],
             'OK CR': [{'cite_type': 'neutral',
                        'editions': {'OKCR': (datetime.date(1750, 1, 1),
                                              datetime.date.today())},
                        'mlz_jurisdiction': 'us;ok',
                        'name': 'Oklahoma Neutral Citation',
                        'variations': {}}],
             'Ohio': [{'cite_type': 'state',
                       'editions': {'Ohio': (datetime.date(1821, 1, 1),
                                             datetime.date(1851, 12, 31))},
                       'mlz_jurisdiction': 'us;oh',
                       'name': 'Ohio Reports',
                       'variations': {}}],
             'Ohio App.': [{'cite_type': 'state',
                            'editions': {'Ohio App.': (datetime.date(1913, 1, 1),
                                                       datetime.date.today()),
                                         'Ohio App. 2d': (datetime.date(1913, 1, 1),
                                                          datetime.date.today()),
                                         'Ohio App. 3d': (datetime.date(1913, 1, 1),
                                                          datetime.date.today())},
                            'mlz_jurisdiction': 'us;oh',
                            'name': 'Ohio Appellate Reports',
                            'variations': {'App.': 'Ohio App.',
                                           'O.A.R.': 'Ohio App.',
                                           'O.A.R.2d': 'Ohio App. 2d',
                                           'O.A.R.3d': 'Ohio App. 3d',
                                           'O.App.': 'Ohio App.',
                                           'O.App.2d': 'Ohio App. 2d',
                                           'O.App.3d': 'Ohio App. 3d',
                                           'Oh.A.': 'Ohio App.',
                                           'Oh.A.2d': 'Ohio App. 2d',
                                           'Oh.App.3d': 'Ohio App. 3d'}}],
             'Ohio App. Unrep.': [{'cite_type': 'state',
                                   'editions': {'Ohio App. Unrep.': (datetime.date(1990, 1, 1),
                                                                     datetime.date(1990, 12, 31))},
                                   'mlz_jurisdiction': 'us;oh',
                                   'name': 'Unreported Ohio Appellate Cases (Anderson)',
                                   'variations': {}}],
             'Ohio B.': [{'cite_type': 'state',
                          'editions': {'Ohio B.': (datetime.date(1982, 1, 1),
                                                   datetime.date(1987, 12, 31))},
                          'mlz_jurisdiction': 'us;oh',
                          'name': 'Ohio Bar Reports',
                          'variations': {}}],
             'Ohio C.C.': [{'cite_type': 'state',
                            'editions': {'Ohio C.C.': (datetime.date(1885, 1, 1),
                                                       datetime.date(1901, 12, 31)),
                                         'Ohio C.C. (n.s.)': (datetime.date(1901, 1, 1),
                                                              datetime.date(1922, 12, 31))},
                            'mlz_jurisdiction': 'us;oh',
                            'name': 'Ohio Circuit Court Reports',
                            'variations': {'O.C.C.N.S.': 'Ohio C.C. (n.s.)',
                                           'Oh.Cir.Ct.': 'Ohio C.C.',
                                           'Oh.Cir.Ct.N.S.': 'Ohio C.C. (n.s.)',
                                           'Ohio C.C.N.S.': 'Ohio C.C. (n.s.)',
                                           'Ohio C.C.R.': 'Ohio C.C.',
                                           'Ohio C.C.R.N.S.': 'Ohio C.C. (n.s.)',
                                           'Ohio Cir.Ct.': 'Ohio C.C.',
                                           'Ohio Cir.Ct.(N.S.)': 'Ohio C.C. (n.s.)',
                                           'Ohio Cir.Ct.R.N.S.': 'Ohio C.C. (n.s.)',
                                           'Ohio Cr.Ct.R.': 'Ohio C.C.'}}],
             'Ohio C.C. Dec.': [{'cite_type': 'state',
                                 'editions': {'Ohio C.C. Dec.': (datetime.date(1901, 1, 1),
                                                                 datetime.date(1923, 12, 31))},
                                 'mlz_jurisdiction': 'us;oh',
                                 'name': 'Ohio Circuit Court Decisions',
                                 'variations': {'O.C.C.': 'Ohio C.C. Dec.',
                                                'Ohio Cir.Ct.': 'Ohio C.C. Dec.'}}],
             'Ohio Cir. Dec.': [{'cite_type': 'state',
                                 'editions': {'Ohio Cir. Dec.': (datetime.date(1885, 1, 1),
                                                                 datetime.date(1901, 12, 31))},
                                 'mlz_jurisdiction': 'us;oh',
                                 'name': 'Ohio Circuit Decisions',
                                 'variations': {'O.C.D.': 'Ohio Cir. Dec.',
                                                'Oh.Cir.Dec.': 'Ohio Cir. Dec.',
                                                'Ohio C.D.': 'Ohio Cir. Dec.',
                                                'Ohio C.Dec.': 'Ohio Cir. Dec.'}}],
             'Ohio Dec.': [{'cite_type': 'state',
                            'editions': {'Ohio Dec.': (datetime.date(1894, 1, 1),
                                                       datetime.date(1920, 12, 31))},
                            'mlz_jurisdiction': 'us;oh',
                            'name': 'Ohio Decisions',
                            'variations': {'O.D.': 'Ohio Dec.', 'Oh.Dec.': 'Ohio Dec.'}}],
             'Ohio Dec. Reprint': [{'cite_type': 'state',
                                    'editions': {'Ohio Dec. Reprint': (datetime.date(1840, 1, 1),
                                                                       datetime.date(1873, 12, 31))},
                                    'mlz_jurisdiction': 'us;oh',
                                    'name': 'Ohio Decisions, Reprint',
                                    'variations': {'O.Dec.Rep.': 'Ohio Dec. Reprint',
                                                   'Oh.Dec.(Reprint)': 'Ohio Dec. Reprint'}}],
             'Ohio Law. Abs.': [{'cite_type': 'state',
                                 'editions': {'Ohio Law. Abs.': (datetime.date(1922, 1, 1),
                                                                 datetime.date(1964, 12, 31))},
                                 'mlz_jurisdiction': 'us;oh',
                                 'name': 'Ohio Law Abstracts',
                                 'variations': {'O.L.A.': 'Ohio Law. Abs.',
                                                'O.L.Abs.': 'Ohio Law. Abs.',
                                                'Ohio Abs.': 'Ohio Law. Abs.',
                                                'Ohio L.Abs.': 'Ohio Law. Abs.',
                                                'Ohio Law Abst.': 'Ohio Law. Abs.'}}],
             'Ohio Misc.': [{'cite_type': 'state',
                             'editions': {'Ohio Misc.': (datetime.date(1962, 1, 1),
                                                         datetime.date.today()),
                                          'Ohio Misc. 2d': (datetime.date(1962, 1, 1),
                                                            datetime.date.today())},
                             'mlz_jurisdiction': 'us;oh',
                             'name': 'Ohio Miscellaneous',
                             'variations': {'O.Misc.': 'Ohio Misc.',
                                            'O.Misc.2d': 'Ohio Misc. 2d',
                                            'Ohio Misc.Dec.': 'Ohio Misc.'}}],
             'Ohio N.P.': [{'cite_type': 'state',
                            'editions': {'Ohio N.P.': (datetime.date(1894, 1, 1),
                                                       datetime.date(1934, 12, 31)),
                                         'Ohio N.P. (n.s.)': (datetime.date(1894, 1, 1),
                                                              datetime.date(1934, 12, 31))},
                            'mlz_jurisdiction': 'us;oh',
                            'name': 'Ohio Nisi Prius Reports',
                            'variations': {'O.N.P.': 'Ohio N.P.',
                                           'O.N.P.N.S.': 'Ohio N.P. (n.s.)',
                                           'Oh.N.P.': 'Ohio N.P.',
                                           'Oh.N.P.(N.S).': 'Ohio N.P. (n.s.)',
                                           'Ohio N.P.N.S.': 'Ohio N.P. (n.s.)'}}],
             'Ohio Op.': [{'cite_type': 'state',
                           'editions': {'Ohio Op.': (datetime.date(1934, 1, 1),
                                                     datetime.date(1982, 12, 31)),
                                        'Ohio Op. 2d': (datetime.date(1934, 1, 1),
                                                        datetime.date(1982, 12, 31)),
                                        'Ohio Op. 3d': (datetime.date(1934, 1, 1),
                                                        datetime.date(1982, 12, 31))},
                           'mlz_jurisdiction': 'us;oh',
                           'name': 'Ohio Opinions',
                           'variations': {'O.O.': 'Ohio Op.',
                                          'Ohio Op.2d': 'Ohio Op. 2d',
                                          'Ohio Op.3d': 'Ohio Op. 3d',
                                          'Ohio Ops.': 'Ohio Op.'}}],
             'Ohio St.': [{'cite_type': 'state',
                           'editions': {'Ohio St.': (datetime.date(1840, 1, 1),
                                                     datetime.date(1964, 12, 31)),
                                        'Ohio St. 2d': (datetime.date(1965, 1, 1),
                                                        datetime.date(1991, 12, 31)),
                                        'Ohio St. 3d': (datetime.date(1991, 1, 1),
                                                        datetime.date.today())},
                           'mlz_jurisdiction': 'us;oh',
                           'name': 'Ohio State Reports',
                           'variations': {'O.S.': 'Ohio St.',
                                          'O.S.2d': 'Ohio St. 2d',
                                          'O.S.3d': 'Ohio St. 3d',
                                          'Oh.St.': 'Ohio St.',
                                          'Ohio St.2d': 'Ohio St. 2d',
                                          'Ohio St.3d': 'Ohio St. 3d'}}],
             'Okla.': [{'cite_type': 'state',
                        'editions': {'Okla': (datetime.date(1890, 1, 1),
                                              datetime.date(1953, 12, 31))},
                        'mlz_jurisdiction': 'us;ok',
                        'name': 'Oklahoma Reports',
                        'variations': {}}],
             'Okla. Crim.': [{'editions': {'Okla. Crim.': (datetime.date(1908, 1, 1),
                                                           datetime.date(1953, 12, 31))},
                              'mlz_jurisdiction': '',
                              'name': 'Oklahoma Criminal Reports',
                              'variations': {'O.Cr.': 'Okla. Crim.',
                                             'Okl.Cr.': 'Okla. Crim.',
                                             'Okla.': 'Okla. Crim.',
                                             'Okla.Cr.': 'Okla. Crim.'}}],
             'Or.': [{'cite_type': 'state',
                      'editions': {'Or.': (datetime.date(1853, 1, 1),
                                           datetime.date.today())},
                      'mlz_jurisdiction': 'us;or',
                      'name': 'Oregon Reports',
                      'variations': {'O.': 'Or.'}}],
             'Or. App.': [{'cite_type': 'state',
                           'editions': {'Or. App.': (datetime.date(1969, 1, 1),
                                                     datetime.date.today())},
                           'mlz_jurisdiction': 'us;or',
                           'name': 'Oregon Reports, Court of Appeals',
                           'variations': {'Or.A.': 'Or. App.'}}],
             'Or. Tax': [{'cite_type': 'state',
                          'editions': {'Or. Tax': (datetime.date(1962, 1, 1),
                                                   datetime.date.today())},
                          'mlz_jurisdiction': 'us;or',
                          'name': 'Oregon Tax Reports',
                          'variations': {}}],
             'Overt.': [{'cite_type': 'state',
                         'editions': {'Overt.': (datetime.date(1791, 1, 1),
                                                 datetime.date(1816, 12, 31))},
                         'mlz_jurisdiction': 'us;tn',
                         'name': 'Tennessee Reports, Overton',
                         'variations': {'Tenn.(Overt.)': 'Overt.'}}],
             'P.': [{'cite_type': 'state_regional',
                     'editions': {'P.': (datetime.date(1883, 1, 1),
                                         datetime.date(1931, 12, 31)),
                                  'P.2d': (datetime.date(1931, 1, 1),
                                           datetime.date(2000, 12, 31)),
                                  'P.3d': (datetime.date(2000, 1, 1),
                                           datetime.date.today())},
                     'mlz_jurisdiction': 'us',
                     'name': 'Pacific Reporter',
                     'variations': {'P': 'P.',
                                    'P 2d': 'P.2d',
                                    'P 3d': 'P.3d',
                                    'P. 2d': 'P.2d',
                                    'P. 3d': 'P.3d',
                                    'P.R.': 'P.',
                                    'Pac.': 'P.',
                                    'Pac.R.': 'P.',
                                    'Pac.Rep.': 'P.'}}],
             'P.R. Dec.': [{'cite_type': 'state',
                            'editions': {'P.R. Dec.': (datetime.date(1899, 1, 1),
                                                       datetime.date.today())},
                            'mlz_jurisdiction': 'us;pr',
                            'name': 'Decisiones de Puerto Rico',
                            'variations': {}}],
             'P.R. Offic. Trans.': [{'cite_type': 'state',
                                     'editions': {'P.R. Offic. Trans.': (datetime.date(1978, 1, 1),
                                                                         datetime.date.today())},
                                     'mlz_jurisdiction': 'us;pr',
                                     'name': 'Official Translations of the Opinions of the Supreme Court of Puerto Rico',
                                     'variations': {}}],
             'P.R. Sent.': [{'cite_type': 'state',
                             'editions': {'P.R. Sent.': (datetime.date(1899, 1, 1),
                                                         datetime.date(1902, 12, 31))},
                             'mlz_jurisdiction': 'us;pr',
                             'name': 'Sentencias del Tribunal Supremo de Puerto Rico',
                             'variations': {}}],
             'P.R.R.': [{'cite_type': 'state',
                         'editions': {'P.R.R.': (datetime.date(1899, 1, 1),
                                                 datetime.date(1978, 12, 31))},
                         'mlz_jurisdiction': 'us;pr',
                         'name': 'Puerto Rico Reports',
                         'variations': {'P.R.': 'P.R.R.', 'Puerto Rico': 'P.R.R.'}}],
             'PA': [{'cite_type': 'neutral',
                     'editions': {'PA': (datetime.date(1750, 1, 1),
                                         datetime.date.today())},
                     'mlz_jurisdiction': 'us;pa',
                     'name': 'Pennsylvania Neutral Citation',
                     'variations': {}}],
             'Pa.': [{'cite_type': 'state',
                      'editions': {'Pa.': (datetime.date(1845, 1, 1),
                                           datetime.date.today())},
                      'mlz_jurisdiction': 'us;pa',
                      'name': 'Pennsylvania State Reports',
                      'variations': {'P.S.R.': 'Pa.',
                                     'Pa.Rep.': 'Pa.',
                                     'Pa.St.': 'Pa.',
                                     'Pa.State': 'Pa.',
                                     'Penn.': 'Pa.',
                                     'Penn.Rep.': 'Pa.',
                                     'Penn.St.': 'Pa.',
                                     'Penn.St.R.': 'Pa.'}}],
             'Pa. C.': [{'cite_type': 'state',
                         'editions': {'Pa. C.': (datetime.date(1870, 1, 1),
                                                 datetime.date(1921, 12, 31))},
                         'mlz_jurisdiction': 'us;pa',
                         'name': 'Pennsylvania County Court Reports',
                         'variations': {'P.C.R.': 'Pa. C.',
                                        'Pa.C.C.': 'Pa. C.',
                                        'Pa.Co.Ct.': 'Pa. C.',
                                        'Pa.Co.Ct.R.': 'Pa. C.',
                                        'Pa.County Ct.': 'Pa. C.',
                                        'Penn.Co.Ct.Rep.': 'Pa. C.'}}],
             'Pa. Commw.': [{'cite_type': 'state',
                             'editions': {'Pa. Commw.': (datetime.date(1970, 1, 1),
                                                         datetime.date(1994, 12, 31))},
                             'mlz_jurisdiction': 'us;pa',
                             'name': 'Pennsylvania Commonwealth Court',
                             'variations': {'Pa. Commonwealth Ct.': 'Pa. Commw.',
                                            'Pa.C.': 'Pa. Commw.',
                                            'Pa.Commw.Ct.': 'Pa. Commw.'}}],
             'Pa. D.': [{'cite_type': 'state',
                         'editions': {'Pa. D.': (datetime.date(1892, 1, 1),
                                                 datetime.date(1921, 12, 31))},
                         'mlz_jurisdiction': 'us;pa',
                         'name': 'Pennsylvania District Reports',
                         'variations': {'Dist.Rep.': 'Pa. D.',
                                        'Pa.Dist.': 'Pa. D.',
                                        'Pa.Dist.R.': 'Pa. D.',
                                        'Penn.Dist.Rep.': 'Pa. D.'}}],
             'Pa. D. & C.': [{'cite_type': 'state',
                              'editions': {'Pa. D. & C.': (datetime.date(1921, 1, 1),
                                                           datetime.date.today()),
                                           'Pa. D. & C.2d': (datetime.date(1921, 1, 1),
                                                             datetime.date.today()),
                                           'Pa. D. & C.3d': (datetime.date(1921, 1, 1),
                                                             datetime.date.today()),
                                           'Pa. D. & C.4th': (datetime.date(1921, 1, 1),
                                                              datetime.date.today())},
                              'mlz_jurisdiction': 'us;pa',
                              'name': 'Pennsylvania District and County Reports',
                              'variations': {'Pa.Dist.& C.Rep.': 'Pa. D. & C.',
                                             'Pa.Dist.& Co.': 'Pa. D. & C.'}}],
             'Pa. Super.': [{'cite_type': 'state',
                             'editions': {'Pa. Super.': (datetime.date(1895, 1, 1),
                                                         datetime.date.today())},
                             'mlz_jurisdiction': 'us;pa',
                             'name': 'Pennsylvania Superior Court Reports',
                             'variations': {'Pa. Superior Ct.': 'Pa. Super.',
                                            'Pa.S.': 'Pa. Super.',
                                            'Pa.Super.Ct.': 'Pa. Super.'}}],
             'Paige Ch.': [{'cite_type': 'state',
                            'editions': {'Paige Ch.': (datetime.date(1828, 1, 1),
                                                       datetime.date(1845, 12, 31))},
                            'mlz_jurisdiction': 'us;ny',
                            'name': "Paige's Chancery Reports",
                            'variations': {'Pai.': 'Paige Ch.',
                                           'Pai.Ch.': 'Paige Ch.',
                                           'Paige': 'Paige Ch.'}}],
             'Peck': [{'cite_type': 'state',
                       'editions': {'Peck': (datetime.date(1821, 1, 1),
                                             datetime.date(1824, 12, 31))},
                       'mlz_jurisdiction': 'us;tn',
                       'name': 'Tennessee Reports, Peck',
                       'variations': {'Peck (Tenn.)': 'Peck', 'Tenn.(Peck)': 'Peck'}}],
             'Pelt.': [{'cite_type': 'state',
                        'editions': {'Pelt.': (datetime.date(1917, 1, 1),
                                               datetime.date(1924, 12, 31))},
                        'mlz_jurisdiction': 'us;la',
                        'name': "Peltier's Opinions, Parish at Orleans",
                        'variations': {}}],
             'Pen. & W.': [{'cite_type': 'state',
                            'editions': {'Pen. & W.': (datetime.date(1829, 1, 1),
                                                       datetime.date(1832, 12, 31))},
                            'mlz_jurisdiction': 'us;pa',
                            'name': 'Pennsylvania State Reports, Penrose and Watts',
                            'variations': {'P.& W.': 'Pen. & W.',
                                           'P.R.': 'Pen. & W.',
                                           'Penr.& W.': 'Pen. & W.'}}],
             'Pennewill': [{'cite_type': 'state',
                            'editions': {'Pennewill': (datetime.date(1897, 1, 1),
                                                       datetime.date(1909, 12, 31))},
                            'mlz_jurisdiction': 'us;de',
                            'name': 'Delaware Reports, Pennewill',
                            'variations': {}}],
             'Pennyp.': [{'cite_type': 'state',
                          'editions': {'Pennyp.': (datetime.date(1881, 1, 1),
                                                   datetime.date(1884, 12, 31))},
                          'mlz_jurisdiction': 'us;pa',
                          'name': 'Pennsylvania State Reports, Pennypacker',
                          'variations': {'Penn.': 'Pennyp.',
                                         'Penny.': 'Pennyp.',
                                         'Pennyp.(Pa.)': 'Pennyp.'}}],
             'Pet.': [{'cite_type': 'fed',
                       'editions': {'Pet.': (datetime.date(1828, 1, 1),
                                             datetime.date(1842, 12, 31))},
                       'mlz_jurisdiction': 'us',
                       'name': "Peters' Supreme Court Reports",
                       'variations': {'Pet.S.C.': 'Pet.',
                                      'Peters': 'Pet.',
                                      'U.S.(Pet.)': 'Pet.'}}],
             'Phil. Eq.': [{'cite_type': 'state',
                            'editions': {'Phil. Eq.': (datetime.date(1866, 1, 1),
                                                       datetime.date(1868, 12, 31))},
                            'mlz_jurisdiction': 'us;nc',
                            'name': "North Carolina Reports, Philips' Equity",
                            'variations': {'N.C.(Phil.Eq.)': 'Phil. Eq.',
                                           'Phil.': 'Phil. Eq.',
                                           'Phil.Eq.(N.C.)': 'Phil. Eq.',
                                           'Phill.': 'Phil. Eq.',
                                           'Phillips': 'Phil. Eq.'}}],
             'Phil. Law': [{'cite_type': 'state',
                            'editions': {'Phil. Law': (datetime.date(1866, 1, 1),
                                                       datetime.date(1868, 12, 31))},
                            'mlz_jurisdiction': 'us;nc',
                            'name': "North Carolina Reports, Philips' Law",
                            'variations': {'N.C.(Phil.Law)': 'Phil. Law',
                                           'Phil.': 'Phil. Law',
                                           'Phil.N.C.': 'Phil. Law',
                                           'Phill.': 'Phil. Law',
                                           'Phill.L.(N.C.)': 'Phil. Law',
                                           'Phillips': 'Phil. Law'}}],
             'Pick.': [{'cite_type': 'state',
                        'editions': {'Pick.': (datetime.date(1822, 1, 1),
                                               datetime.date(1839, 12, 31))},
                        'mlz_jurisdiction': 'us;ma',
                        'name': 'Massachusetts Reports, Pickering',
                        'variations': {'Mass.(Pick.)': 'Pick.', 'Pick.(Mass.)': 'Pick.'}}],
             'Pin.': [{'cite_type': 'state',
                       'editions': {'Pin.': (datetime.date(1839, 1, 1),
                                             datetime.date(1852, 12, 31))},
                       'mlz_jurisdiction': 'us;wi',
                       'name': 'Wisconsin Reports, Pinney',
                       'variations': {'Pinn.': 'Pin.'}}],
             'Port.': [{'cite_type': 'state',
                        'editions': {'Port.': (datetime.date(1834, 1, 1),
                                               datetime.date(1839, 12, 31))},
                        'mlz_jurisdiction': 'us;al',
                        'name': 'Alabama Reports, Porter',
                        'variations': {'Port.(Ala.)': 'Port.', 'Porter': 'Port.'}}],
             'R.I.': [{'cite_type': 'state',
                       'editions': {'R.I.': (datetime.date(1828, 1, 1),
                                             datetime.date(1980, 12, 31))},
                       'mlz_jurisdiction': 'us;ri',
                       'name': 'Rhode Island Reports',
                       'variations': {}}],
             'Rand.': [{'cite_type': 'state',
                        'editions': {'Rand.': (datetime.date(1821, 1, 1),
                                               datetime.date(1828, 12, 31))},
                        'mlz_jurisdiction': 'us;va',
                        'name': 'Virginia Reports, Randolph',
                        'variations': {'Va.(Rand.)': 'Rand.'}}],
             'Rawle': [{'cite_type': 'state',
                        'editions': {'Rawle': (datetime.date(1828, 1, 1),
                                               datetime.date(1835, 12, 31))},
                        'mlz_jurisdiction': 'us;pa',
                        'name': 'Pennsylvania State Reports, Rawle',
                        'variations': {'Pa. Rawle': 'Rawle',
                                       'R.': 'Rawle',
                                       'Raw.': 'Rawle'}}],
             'Rice': [{'cite_type': 'state',
                       'editions': {'Rice': (datetime.date(1838, 1, 1),
                                             datetime.date(1839, 12, 31))},
                       'mlz_jurisdiction': 'us;sc',
                       'name': 'South Carolina Reports, Rice',
                       'variations': {'Rice L.(S.C.)': 'Rice', 'S.C.L.(Rice)': 'Rice'}}],
             'Rice Eq.': [{'cite_type': 'state',
                           'editions': {'Rice Eq.': (datetime.date(1838, 1, 1),
                                                     datetime.date(1839, 12, 31))},
                           'mlz_jurisdiction': 'us;sc',
                           'name': "South Carolina Reports, Rice's Equity",
                           'variations': {'Rice Ch.': 'Rice Eq.',
                                          'S.C.Eq.(Rice.Eq.)': 'Rice Eq.'}}],
             'Rich.': [{'cite_type': 'state',
                        'editions': {'Rich.': (datetime.date(1846, 1, 1),
                                               datetime.date(1868, 12, 31))},
                        'mlz_jurisdiction': 'us;sc',
                        'name': 'South Carolina Reports, Richardson',
                        'variations': {'Rich.L.(S.C.)': 'Rich.',
                                       'Rich.Law(S.C.)': 'Rich.',
                                       'S.C.L.(Rich.)': 'Rich.'}}],
             'Rich. Cas.': [{'cite_type': 'state',
                             'editions': {'Rich. Cas.': (datetime.date(1831, 1, 1),
                                                         datetime.date(1832, 12, 31))},
                             'mlz_jurisdiction': 'us;sc',
                             'name': "South Carolina Reports, Richardson's Cases",
                             'variations': {'Rich.Cas.(S.C.)': 'Rich. Cas.',}}],
             'Rich. Eq.': [{'cite_type': 'state',
                            'editions': {'Rich. Eq.': (datetime.date(1844, 1, 1),
                                                       datetime.date(1868, 12, 31))},
                            'mlz_jurisdiction': 'us;sc',
                            'name': "South Carolina Reports, Richardson's Equity",
                            'variations': {'Rich.Eq.Ch.': 'Rich. Eq.',
                                           'S.C.Eq.(Rich.Eq.)': 'Rich. Eq.'}}],
             'Ril.': [{'cite_type': 'state',
                       'editions': {'Ril.': (datetime.date(1836, 1, 1),
                                             datetime.date(1837, 12, 31))},
                       'mlz_jurisdiction': 'us;sc',
                       'name': 'South Carolina Reports, Riley',
                       'variations': {'Riley': 'Ril.',
                                      'Riley L.(S.C.)': 'Ril.',
                                      'S.C.L.(Riley)': 'Ril.'}}],
             'Ril. Eq.': [{'cite_type': 'state',
                           'editions': {'Ril. Eq.': (datetime.date(1836, 1, 1),
                                                     datetime.date(1837, 12, 31))},
                           'mlz_jurisdiction': 'us;sc',
                           'name': "South Carolina Reports, Riley's Chancery",
                           'variations': {'Ril.': 'Ril. Eq.',
                                          'Riley': 'Ril. Eq.',
                                          'Riley Ch.': 'Ril. Eq.',
                                          'Riley Eq.': 'Ril. Eq.',
                                          'Riley Eq.(S.C.)': 'Ril. Eq.',
                                          'S.C.Eq.(Ril.)': 'Ril. Eq.'}}],
             'Rob.': [{'cite_type': 'state',
                       'editions': {'Rob.': (datetime.date(1841, 1, 1),
                                             datetime.date(1846, 12, 31))},
                       'mlz_jurisdiction': 'us;la',
                       'name': 'Louisiana Reports, Robinson',
                       'variations': {'Rob.La.': 'Rob.', 'Robinson': 'Rob.'}},
                      {'cite_type': 'state',
                       'editions': {'Rob.': (datetime.date(1842, 1, 1),
                                             datetime.date(1844, 12, 31))},
                       'mlz_jurisdiction': 'us;va',
                       'name': 'Virginia Reports, Robinson',
                       'variations': {'Rob.Va.': 'Rob.',
                                      'Robinson': 'Rob.',
                                      'Va.(Rob.)': 'Rob.'}}],
             'Robards': [{'cite_type': 'state',
                          'editions': {'Robards': (datetime.date(1862, 1, 1),
                                                   datetime.date(1865, 12, 31))},
                          'mlz_jurisdiction': 'us;tx',
                          'name': 'Synopses of the Decisions of the Supreme Court of Texas Arising from Restraints by Conscript and Other Military Authorities (Robards)',
                          'variations': {'Rob.': 'Robards',
                                         'Rob.Cons.Cas.(Tex.)': 'Robards',
                                         'Rob.Consc.Cas.': 'Robards',
                                         'Robard': 'Robards'}}],
             'Root': [{'cite_type': 'state',
                       'editions': {'Root': (datetime.date(1789, 1, 1),
                                             datetime.date(1798, 12, 31))},
                       'mlz_jurisdiction': 'us;ct',
                       'name': 'Root\'s Connecticut Reports',
                       'variations': {}}],
             'S. & M.': [{'cite_type': 'state',
                          'editions': {'S. & M.': (datetime.date(1843, 1, 1),
                                                   datetime.date(1850, 12, 31))},
                          'mlz_jurisdiction': 'us;ms',
                          'name': 'Mississippi Reports, Smedes and Marshall',
                          'variations': {'Miss.(S.& M.)': 'S. & M.',
                                         'S.& Mar.': 'S. & M.',
                                         'Sm.& M.': 'S. & M.',
                                         'Smed.& M.': 'S. & M.',
                                         'Smedes & M.(Miss.)': 'S. & M.'}}],
             'S. Ct.': [{'cite_type': 'fed',
                         'editions': {'S. Ct.': (datetime.date(1882, 1, 1),
                                                 datetime.date.today())},
                         'mlz_jurisdiction': 'us',
                         'name': "West's Supreme Court Reporter",
                         'variations': {'S Ct': 'S. Ct.',
                                        'S.C.': 'S. Ct.',
                                        'S.Ct.': 'S. Ct.',
                                        'Sup.Ct.': 'S. Ct.',
                                        'Sup.Ct.Rep.': 'S. Ct.',
                                        'Supr.Ct.Rep.': 'S. Ct.'}}],
             'S.C.': [{'cite_type': 'state',
                       'editions': {'S.C.': (datetime.date(1868, 1, 1),
                                             datetime.date.today())},
                       'mlz_jurisdiction': 'us;sc',
                       'name': 'South Carolina Reports',
                       'variations': {'S.C.R.': 'S.C.',
                                      'S.Car.': 'S.C.',
                                      'So.C.': 'S.C.',
                                      'So.Car.': 'S.C.',
                                      'South Car.': 'S.C.'}}],
             'S.D.': [{'cite_type': 'state',
                       'editions': {'S.D.': (datetime.date(1890, 1, 1),
                                             datetime.date(1976, 12, 31))},
                       'mlz_jurisdiction': 'us;sd',
                       'name': 'South Dakota Reports',
                       'variations': {'S.Dak.': 'S.D.'}}],
             'S.E.': [{'cite_type': 'state_regional',
                       'editions': {'S.E.': (datetime.date(1887, 1, 1),
                                             datetime.date(1939, 12, 31)),
                                    'S.E.2d': (datetime.date(1939, 1, 1),
                                               datetime.date.today())},
                       'mlz_jurisdiction': 'us',
                       'name': 'South Eastern Reporter',
                       'variations': {'S. E.': 'S.E.',
                                      'S. E. 2d': 'S.E.2d',
                                      'S. E.2d': 'S.E.2d',
                                      'S.E. 2d': 'S.E.2d',
                                      'SE': 'S.E.',
                                      'SE 2d': 'S.E.2d'}}],
             'S.W.': [{'cite_type': 'state_regional',
                       'editions': {'S.W.': (datetime.date(1886, 1, 1),
                                             datetime.date(1928, 12, 31)),
                                    'S.W.2d': (datetime.date(1928, 1, 1),
                                               datetime.date(1999, 12, 31)),
                                    'S.W.3d': (datetime.date(1999, 1, 1),
                                               datetime.date.today())},
                       'mlz_jurisdiction': 'us',
                       'name': 'South Western Reporter',
                       'variations': {'S. W.': 'S.W.',
                                      'S. W. 2d': 'S.W.2d',
                                      'S. W. 3d': 'S.W.3d',
                                      'S. W.2d': 'S.W.2d',
                                      'S. W.3d': 'S.W.3d',
                                      'S.W. 2d': 'S.W.2d',
                                      'S.W. 3d': 'S.W.3d',
                                      'SW': 'S.W.',
                                      'SW 2d': 'S.W.2d',
                                      'SW 3d': 'S.W.3d'}}],
             'SD': [{'cite_type': 'neutral',
                     'editions': {'SD': (datetime.date(1750, 1, 1),
                                         datetime.date.today())},
                     'mlz_jurisdiction': 'us;sd',
                     'name': 'South Dakota Neutral Citation',
                     'variations': {}}],
             'Sadler': [{'cite_type': 'state',
                         'editions': {'Sadler': (datetime.date(1885, 1, 1),
                                                 datetime.date(1888, 12, 31))},
                         'mlz_jurisdiction': 'us;pa',
                         'name': 'Pennsylvania State Reports, Sadler',
                         'variations': {'Pa.Cas.': 'Sadler',
                                        'Sad.Pa.Cas.': 'Sadler',
                                        'Sad.Pa.Cs.': 'Sadler',
                                        'Sadl.': 'Sadler',
                                        'Sadler(Pa.)': 'Sadler'}}],
             'Sand. Ch.': [{'cite_type': 'state',
                            'editions': {'Sand. Ch.': (datetime.date(1843, 1, 1),
                                                       datetime.date(1847, 12, 31))},
                            'mlz_jurisdiction': 'us;ny',
                            'name': "Sandford's Chancery Reports",
                            'variations': {'Sand.Chy.': 'Sand. Ch.',
                                           'Sandf.Ch.': 'Sand. Ch.',
                                           'Sandf.Ch.(N.Y.)': 'Sand. Ch.',
                                           'Sandf.Chy.': 'Sand. Ch.'}}],
             'Sarat. Ch. Sent.': [{'cite_type': 'state',
                                   'editions': {'Sarat. Ch. Sent.': (datetime.date(1841, 1, 1),
                                                                     datetime.date(1847, 12, 31))},
                                   'mlz_jurisdiction': 'us;ny',
                                   'name': 'Saratoga Chancery Sentinel',
                                   'variations': {'Ch.Sent.': 'Sarat. Ch. Sent.',
                                                  'Ch.Sent.(N.Y.)': 'Sarat. Ch. Sent.',
                                                  'N.Y.Ch.Sent.': 'Sarat. Ch. Sent.',
                                                  'Sar.Ch.Sen.': 'Sarat. Ch. Sent.'}}],
             'Scam.': [{'cite_type': 'state',
                        'editions': {'Scam.': (datetime.date(1832, 1, 1),
                                               datetime.date(1843, 12, 31))},
                        'mlz_jurisdiction': 'us;il',
                        'name': 'Illinois Reports, Scammon',
                        'variations': {'Ill.(Scam.)': 'Scam.', 'Sc.': 'Scam.'}}],
             'Serg. & Rawle': [{'cite_type': 'state',
                                'editions': {'Serg. & Rawle': (datetime.date(1814, 1, 1),
                                                               datetime.date(1828, 12, 31))},
                                'mlz_jurisdiction': 'us;pa',
                                'name': 'Pennsylvania State Reports, Sergeant and Rawle',
                                'variations': {'Serg.& R.': 'Serg. & Rawle',
                                               'Serg.& Raw.': 'Serg. & Rawle',
                                               'Serg.& Rawl.': 'Serg. & Rawle'}}],
             'Sneed': [{'cite_type': 'state',
                        'editions': {'Sneed': (datetime.date(1801, 1, 1),
                                               datetime.date(1805, 12, 31))},
                        'mlz_jurisdiction': 'us;ky',
                        'name': 'Kentucky Reports, Sneed',
                        'variations': {'Ken.Dec.': 'Sneed',
                                       'Ky.(Sneed)': 'Sneed',
                                       'Sneed Dec.': 'Sneed'}},
                       {'cite_type': 'state',
                        'editions': {'Sneed': (datetime.date(1853, 1, 1),
                                               datetime.date(1858, 12, 31))},
                        'mlz_jurisdiction': 'us;tn',
                        'name': 'Tennessee Reports, Sneed',
                        'variations': {'Tenn.(Sneed)': 'Sneed'}}],
             'So.': [{'cite_type': 'state_regional',
                      'editions': {'So.': (datetime.date(1886, 1, 1),
                                           datetime.date(1941, 12, 31)),
                                   'So. 2d': (datetime.date(1941, 1, 1),
                                              datetime.date(2008, 12, 31)),
                                   'So. 3d': (datetime.date(2008, 1, 1),
                                              datetime.date.today())},
                      'mlz_jurisdiction': 'us',
                      'name': 'Southern Reporter',
                      'variations': {'So.2d': 'So. 2d',
                                     'So.3d': 'So. 3d',
                                     'South.': 'So.',
                                     'South.2d': 'So. 2d',
                                     'South.3d': 'So. 3d'}}],
             'Speers': [{'cite_type': 'state',
                         'editions': {'Speers': (datetime.date(1842, 1, 1),
                                                 datetime.date(1844, 12, 31))},
                         'mlz_jurisdiction': 'us;sc',
                         'name': 'South Carolina Reports, Speers',
                         'variations': {'S.C.L.(Speers)': 'Speers',
                                        'Sp.': 'Speers',
                                        'Spears': 'Speers',
                                        'Speers L.(S.C.)': 'Speers'}}],
             'Speers Eq.': [{'cite_type': 'state',
                             'editions': {'Speers Eq.': (datetime.date(1842, 1, 1),
                                                         datetime.date(1844, 12, 31))},
                             'mlz_jurisdiction': 'us;sc',
                             'name': "South Carolina Reports, Speers' Equity",
                             'variations': {'S.C.Eq.(Speers Eq.)': 'Speers Eq.',
                                            'Sp.': 'Speers Eq.',
                                            'Sp.Ch.': 'Speers Eq.',
                                            'Spear Ch.': 'Speers Eq.',
                                            'Spear Eq.': 'Speers Eq.',
                                            'Spears': 'Speers Eq.',
                                            'Spears Eq.': 'Speers Eq.',
                                            'Speers': 'Speers Eq.',
                                            'Speers Eq.(S.C.)': 'Speers Eq.'}}],
             'State Rptr.': [{'cite_type': 'state',
                              'editions': {'State Rptr.': (datetime.date(1945, 1, 1),
                                                           datetime.date.today())},
                              'mlz_jurisdiction': 'us;mt',
                              'name': 'State Reporter',
                              'variations': {}}],
             'Stew': [{'cite_type': 'state',
                       'editions': {'Stew.': (datetime.date(1827, 1, 1),
                                              datetime.date(1831, 12, 31))},
                       'mlz_jurisdiction': 'us;al',
                       'name': 'Alabama Reports, Stewart',
                       'variations': {'Stewart': 'Stew.'}}],
             'Stew. & P.': [{'cite_type': 'state',
                             'editions': {'Stew. & P.': (datetime.date(1831, 1, 1),
                                                         datetime.date(1834, 1, 1))},
                             'mlz_jurisdiction': 'us;al',
                             'name': 'Alabama Reports, Stewart and Porter',
                             'variations': {}}],
             'Strob.': [{'cite_type': 'state',
                         'editions': {'Strob.': (datetime.date(1846, 1, 1),
                                                 datetime.date(1850, 12, 31))},
                         'mlz_jurisdiction': 'us;sc',
                         'name': 'South Carolina Reports, Strobhart',
                         'variations': {'S.C.L.(Strob.)': 'Strob.',
                                        'Strobh.L.(S.C.)': 'Strob.'}}],
             'Strob. Eq.': [{'cite_type': 'state',
                             'editions': {'Strob. Eq.': (datetime.date(1846, 1, 1),
                                                         datetime.date(1850, 12, 31))},
                             'mlz_jurisdiction': 'us;sc',
                             'name': "South Carolina Reports, Strobhart's Equity",
                             'variations': {'S.C.Eq.(Strob.Eq.)': 'Strob. Eq.',
                                            'Strob.Eq.(S.C.)': 'Strob. Eq.'}}],
             'Swan': [{'cite_type': 'state',
                       'editions': {'Swan': (datetime.date(1851, 1, 1),
                                             datetime.date(1853, 12, 31))},
                       'mlz_jurisdiction': 'us;tn',
                       'name': 'Tennessee Reports, Swan',
                       'variations': {'Tenn.(Swan)': 'Swan'}}],
             'T.B. Mon.': [{'cite_type': 'state',
                            'editions': {'T.B. Mon.': (datetime.date(1824, 1, 1),
                                                       datetime.date(1828, 12, 31))},
                            'mlz_jurisdiction': 'us;ky',
                            'name': 'Kentucky Reports, Monroe, T.B.',
                            'variations': {'Ky.(T.B.Monroe)': 'T.B. Mon.',
                                           'Mon.': 'T.B. Mon.',
                                           'Mon.T.B.': 'T.B. Mon.',
                                           'T.B.Mon.(Ky.)': 'T.B. Mon.'}}],
             'T.C.': [{'cite_type': 'fed',
                       'editions': {'T.C.': (datetime.date(1942, 1, 1),
                                             datetime.date.today())},
                       'mlz_jurisdiction': 'us',
                       'name': 'Reports of the United States Tax Court',
                       'variations': {'T. C.': 'T.C.', 'T.Ct': 'T.C.', 'T.Ct.': 'T.C.'}}],
             'T.C.M.': [{'editions': {'T.C.M. (CCH)': (datetime.date(1942, 1, 1),
                                                       datetime.date.today()),
                                      'T.C.M. (P-H)': (datetime.date(1942, 1, 1),
                                                       datetime.date.today()),
                                      'T.C.M. (RIA)': (datetime.date(1991, 1, 1),
                                                       datetime.date.today())},
                         'mlz_jurisdiction': 'us',
                         'name': 'Tax Court Memorandum Decisions',
                         'variations': {}}],
             'Tay.': [{'cite_type': 'state',
                       'editions': {'Tay.': (datetime.date(1798, 1, 1),
                                             datetime.date(1802, 12, 31))},
                       'mlz_jurisdiction': 'us;nc',
                       'name': 'North Carolina Reports, Taylor',
                       'variations': {'N.C.(Tay.)': 'Tay.',
                                      'Tay.J.L.': 'Tay.',
                                      'Tay.N.C.': 'Tay.',
                                      'Tayl.N.C.': 'Tay.',
                                      'Taylor': 'Tay.'}}],
             'Taylor': [{'cite_type': 'state',
                         'editions': {'Taylor': (datetime.date(1816, 1, 1),
                                                 datetime.date(1818, 12, 31))},
                         'mlz_jurisdiction': 'us;nc',
                         'name': "Taylor's North Carolina Term Reports",
                         'variations': {'N.C.(Taylor)': 'Taylor',
                                        'N.C.T.Rep.': 'Taylor',
                                        'N.C.Term.R.': 'Taylor',
                                        'N.C.Term.Rep.': 'Taylor'}}],
             'Teiss.': [{'cite_type': 'state',
                         'editions': {'Teiss.': (datetime.date(1903, 1, 1),
                                                 datetime.date(1917, 12, 31))},
                         'mlz_jurisdiction': 'us;la',
                         'name': 'Louisiana Court of Appeals Reports, Teisser',
                         'variations': {'La.App.(Orleans)': 'Teiss.',
                                        'Teissier': 'Teiss.'}}],
             'Tenn.': [{'cite_type': 'state',
                        'editions': {'Tenn.': (datetime.date(1870, 1, 1),
                                               datetime.date(1971, 12, 31))},
                        'mlz_jurisdiction': 'us;tn',
                        'name': 'Tennessee Reports',
                        'variations': {'Ten.': 'Tenn.'}}],
             'Tenn. App.': [{'cite_type': 'state',
                             'editions': {'Tenn. App.': (datetime.date(1925, 1, 1),
                                                         datetime.date(1971, 12, 31))},
                             'mlz_jurisdiction': 'us;tn',
                             'name': 'Tennessee Appeals Reports',
                             'variations': {}}],
             'Tenn. Crim. App.': [{'cite_type': 'state',
                                   'editions': {'Tenn. Crim. App.': (datetime.date(1967, 1, 1),
                                                                     datetime.date(1971, 12, 31))},
                                   'mlz_jurisdiction': 'us;tn',
                                   'name': 'Tennessee Criminal Appeals Reports',
                                   'variations': {}}],
             'Tex.': [{'cite_type': 'state',
                       'editions': {'Tex.': (datetime.date(1846, 1, 1),
                                             datetime.date(1962, 12, 31))},
                       'mlz_jurisdiction': 'us;tx',
                       'name': 'Texas Reports',
                       'variations': {'Tex.S.Ct.': 'Tex.'}}],
             'Tex. Civ. App.': [{'cite_type': 'state',
                                 'editions': {'Tex. Civ. App.': (datetime.date(1892, 1, 1),
                                                                 datetime.date(1911, 12, 31))},
                                 'mlz_jurisdiction': 'us;tx',
                                 'name': 'Texas Civil Appeals Reports',
                                 'variations': {'Tex.Civ.App.': 'Tex. Civ. App.'}}],
             'Tex. Crim': [{'cite_type': 'state',
                            'editions': {'Tex. Crim.': (datetime.date(1891, 1, 1),
                                                        datetime.date(1962, 12, 31))},
                            'mlz_jurisdiction': 'us;tx',
                            'name': 'Texas Criminal Reports',
                            'variations': {'Tex.Cr.App.': 'Tex. Crim.',
                                           'Tex.Cr.R.': 'Tex. Crim.',
                                           'Tex.Crim.Rep.': 'Tex. Crim.'}}],
             'Tex. Ct. App.': [{'cite_type': 'state',
                                'editions': {'Tex. Ct. App.': (datetime.date(1876, 1, 1),
                                                               datetime.date(1891, 12, 31))},
                                'mlz_jurisdiction': 'us;tx',
                                'name': 'Texas Court of Appeals Reports',
                                'variations': {'Tex.Ct.App.R.': 'Tex. Ct. App.'}}],
             'Tex. L. Rev.': [{'cite_type': 'state',
                               'editions': {'Tex. L. Rev.': (datetime.date(1845, 1, 1),
                                                             datetime.date(1846, 12, 31))},
                               'mlz_jurisdiction': 'us;tx',
                               'name': 'Texas Law Review',
                               'variations': {'Texas L.Rev.': 'Tex. L. Rev.'}}],
             'Tex. Sup. Ct. J.': [{'cite_type': 'state',
                                   'editions': {'Tex. Sup. Ct. J.': (datetime.date(1957, 1, 1),
                                                                     datetime.date.today())},
                                   'mlz_jurisdiction': 'us;tx',
                                   'name': 'Texas Supreme Court Journal',
                                   'variations': {}}],
             'Tread.': [{'cite_type': 'state',
                         'editions': {'Tread.': (datetime.date(1812, 1, 1),
                                                 datetime.date(1816, 12, 31))},
                         'mlz_jurisdiction': 'us;sc',
                         'name': 'South Carolina Reports, Treadway',
                         'variations': {'S.C.L.(Tread.)': 'Tread.'}}],
             'Tuck. & Cl.': [{'cite_type': 'state',
                              'editions': {'Tuck. & Cl.': (datetime.date(1892, 1, 1),
                                                           datetime.date(1893, 12, 31))},
                              'mlz_jurisdiction': 'us;dc',
                              'name': 'District of Columbia Reports, Tucker and Clephane',
                              'variations': {'D.C.(Tuck.& Cl.)': 'Tuck. & Cl.',
                                             'Tuck.': 'Tuck. & Cl.',
                                             'Tuck.& C.': 'Tuck. & Cl.'}}],
             'Tyl.': [{'cite_type': 'state',
                       'editions': {'Tyl.': (datetime.date(1800, 1, 1),
                                             datetime.date(1803, 12, 31))},
                       'mlz_jurisdiction': 'us;vt',
                       'name': 'Vermont Reports, Tyler',
                       'variations': {'Tyler': 'Tyl.'}}],
             'Tyng': [{'cite_type': 'state',
                       'editions': {'Tyng': (datetime.date(1806, 1, 1),
                                             datetime.date(1822, 12, 31))},
                       'mlz_jurisdiction': 'us;ma',
                       'name': 'Massachusetts Reports, Tyng',
                       'variations': {'Mass.(Tyng)': 'Tyng'}}],
             'U.S.': [{'cite_type': 'fed',
                       'editions': {'U.S.': (datetime.date(1790, 1, 1),
                                             datetime.date.today())},
                       'mlz_jurisdiction': 'us',
                       'name': 'United States Supreme Court Reports',
                       'variations': {'U. S.': 'U.S.',
                                      'U.S.S.C.Rep.': 'U.S.',
                                      'USSCR': 'U.S.'}}],
             'U.S. App. D.C.': [{'cite_type': 'state',
                                 'editions': {'U.S. App. D.C.': (datetime.date(1941, 1, 1),
                                                                 datetime.date.today())},
                                 'mlz_jurisdiction': 'us;dc',
                                 'name': 'United States Court of Appeals Reports',
                                 'variations': {}}],
             'U.S.L.W.': [{'editions': {'U.S.L.W.': (datetime.date(1933, 1, 1),
                                                     datetime.date.today())},
                           'mlz_jurisdiction': 'us',
                           'name': 'United States Law Week',
                           'variations': {}}],
             'UT': [{'cite_type': 'neutral',
                     'editions': {'UT': (datetime.date(1750, 1, 1),
                                         datetime.date.today())},
                     'mlz_jurisdiction': 'us;ut',
                     'name': 'Utah Neutral Citation',
                     'variations': {}}],
             'UT App': [{'cite_type': 'neutral',
                         'editions': {'UT App': (datetime.date(1750, 1, 1),
                                                 datetime.date.today())},
                         'mlz_jurisdiction': 'us;ut',
                         'name': 'Utah Neutral Citation',
                         'variations': {}}],
             'Utah': [{'cite_type': 'state',
                       'editions': {'Utah': (datetime.date(1851, 1, 1),
                                             datetime.date(1974, 12, 31)),
                                    'Utah 2d': (datetime.date(1851, 1, 1),
                                                datetime.date(1974, 12, 31))},
                       'mlz_jurisdiction': 'us;ut',
                       'name': 'Utah Reports',
                       'variations': {}}],
             'V.I': [{'cite_type': 'state',
                      'editions': {'V.I.': (datetime.date(1917, 1, 1),
                                            datetime.date.today())},
                      'mlz_jurisdiction': 'us;vi',
                      'name': 'Virgin Islands Reports',
                      'variations': {}}],
             'VT': [{'cite_type': 'neutral',
                     'editions': {'VT': (datetime.date(1750, 1, 1),
                                         datetime.date.today())},
                     'mlz_jurisdiction': 'us;vt',
                     'name': 'Vermont Neutral Citation',
                     'variations': {}}],
             'Va.': [{'cite_type': 'state',
                      'editions': {'Va.': (datetime.date(1880, 1, 1),
                                           datetime.date.today())},
                      'mlz_jurisdiction': 'us;va',
                      'name': 'Virginia Reports',
                      'variations': {'V.': 'Va.', 'Virg.': 'Va.'}}],
             'Va. App.': [{'cite_type': 'state',
                           'editions': {'Va. App.': (datetime.date(1985, 1, 1),
                                                     datetime.date.today())},
                           'mlz_jurisdiction': 'us;va',
                           'name': 'Virginia Court of Appeals Reports',
                           'variations': {}}],
             'Va. Cas.': [{'cite_type': 'state',
                           'editions': {'Va. Cas.': (datetime.date(1789, 1, 1),
                                                     datetime.date(1826, 12, 31))},
                           'mlz_jurisdiction': 'us;va',
                           'name': 'Virginia Cases, Criminal',
                           'variations': {}}],
             'Vet. App.': [{'cite_type': 'fed',
                            'editions': {'Vet. App.': (datetime.date(1990, 1, 1),
                                                       datetime.date.today())},
                            'mlz_jurisdiction': 'us',
                            'name': 'Veterans Appeals Reporter',
                            'variations': {'Vet.App.': 'Vet. App.'}}],
             'Vt.': [{'cite_type': 'state',
                      'editions': {'Vt.': (datetime.date(1826, 1, 1),
                                           datetime.date.today())},
                      'mlz_jurisdiction': 'us;vt',
                      'name': 'Vermont Reports',
                      'variations': {'V.R.': 'Vt.', 'Verm.': 'Vt.'}}],
             'W. Va.': [{'cite_type': 'state',
                         'editions': {'W. Va': (datetime.date(1864, 1, 1),
                                                datetime.date.today())},
                         'mlz_jurisdiction': 'us;wv',
                         'name': 'West Virginia Reports',
                         'variations': {'W.V.': 'W. Va', 'West Va.': 'W. Va'}}],
             'WI': [{'cite_type': 'neutral',
                     'editions': {'WI': (datetime.date(1750, 1, 1),
                                         datetime.date.today())},
                     'mlz_jurisdiction': 'us;wi',
                     'name': 'Wisconsin Neutral Citation',
                     'variations': {}}],
             'WI App': [{'cite_type': 'neutral',
                         'editions': {'WIS': (datetime.date(1750, 1, 1),
                                              datetime.date.today())},
                         'mlz_jurisdiction': 'us;wi',
                         'name': 'Wisconsin Neutral Citation',
                         'variations': {}}],
             'WY': [{'cite_type': 'neutral',
                     'editions': {'WY': (datetime.date(1750, 1, 1),
                                         datetime.date.today())},
                     'mlz_jurisdiction': 'us;wy',
                     'name': 'Wyoming Neutral Citation',
                     'variations': {}}],
             'Walk.': [{'cite_type': 'state',
                        'editions': {'Walk': (datetime.date(1855, 1, 1),
                                              datetime.date(1885, 12, 31))},
                        'mlz_jurisdiction': 'us;pa',
                        'name': 'Pennsylvania State Reports, Walker',
                        'variations': {'Walk.Pa.': 'Walk', 'Walker': 'Walk'}}],
             'Walker': [{'cite_type': 'state',
                         'editions': {'Walker': (datetime.date(1818, 1, 1),
                                                 datetime.date(1832, 12, 31))},
                         'mlz_jurisdiction': 'us;ms',
                         'name': 'Mississippi Reports, Walker',
                         'variations': {'Miss.(Walker)': 'Walker',
                                        'Walk.': 'Walker',
                                        'Walk.Miss.': 'Walker'}}],
             'Wall.': [{'cite_type': 'fed',
                        'editions': {'Wall.': (datetime.date(1863, 1, 1),
                                               datetime.date(1874, 12, 31))},
                        'mlz_jurisdiction': 'us',
                        'name': "Wallace's Supreme Court Reports",
                        'variations': {'U.S.(Wall.)': 'Wall.',
                                       'Wall.': 'Wall.',
                                       'Wall.Rep.': 'Wall.',
                                       'Wall.S.C.': 'Wall.'}}],
             'Wash.': [{'cite_type': 'state',
                        'editions': {'Wash.': (datetime.date(1790, 1, 1),
                                               datetime.date(1796, 12, 31))},
                        'mlz_jurisdiction': 'us;va',
                        'name': 'Virginia Reports, Washington',
                        'variations': {'Va.(Wash.)': 'Wash.', 'Wash.Va.': 'Wash.'}},
                       {'cite_type': 'state',
                        'editions': {'Wash.': (datetime.date(1889, 1, 1),
                                               datetime.date.today()),
                                     'Wash. 2d': (datetime.date(1889, 1, 1),
                                                  datetime.date.today())},
                        'mlz_jurisdiction': 'us;wa',
                        'name': 'Washington Reports',
                        'variations': {'W.': 'Wash.',
                                       'W.2d': 'Wash. 2d',
                                       'W.St.': 'Wash.',
                                       'WASH': 'Wash.',
                                       'Wa.': 'Wash.',
                                       'Wa.2d': 'Wash. 2d',
                                       'Wash.St.': 'Wash.',
                                       'Wn': 'Wash.',
                                       'Wn. 2d': 'Wash. 2d',
                                       'Wn.2d': 'Wash. 2d'}}],
             'Wash. App.': [{'cite_type': 'state',
                             'editions': {'Wash. App.': (datetime.date(1969, 1, 1),
                                                         datetime.date.today())},
                             'mlz_jurisdiction': 'us;wa',
                             'name': 'Washington Appellate Reports',
                             'variations': {'W.App.': 'Wash. App.',
                                            'Wa.A.': 'Wash. App.',
                                            'Wn. App.': 'Wash. App.',
                                            'Wn.App.': 'Wash. App.'}}],
             'Wash. Terr.': [{'cite_type': 'state',
                              'editions': {'Wash. Terr.': (datetime.date(1854, 1, 1),
                                                           datetime.date(1888, 12, 31))},
                              'mlz_jurisdiction': 'us;wa',
                              'name': 'Washington Territory Reports',
                              'variations': {'Allen': 'Wash. Terr.',
                                             'W.T.': 'Wash. Terr.',
                                             'W.Ty.R.': 'Wash. Terr.',
                                             'Wash.': 'Wash. Terr.',
                                             'Wash.T.': 'Wash. Terr.',
                                             'Wash.Ter.': 'Wash. Terr.',
                                             'Wash.Ter.N.S.': 'Wash. Terr.',
                                             'Wash.Ty.': 'Wash. Terr.',
                                             'Wn. Terr.': 'Wash. Terr.'}}],
             'Watts': [{'cite_type': 'state',
                        'editions': {'Watts': (datetime.date(1832, 1, 1),
                                               datetime.date(1840, 12, 31))},
                        'mlz_jurisdiction': 'us;pa',
                        'name': 'Pennsylvania State Reports, Watts',
                        'variations': {'Wa.': 'Watts', 'Watts(Pa.)': 'Watts'}}],
             'Watts & Serg.': [{'cite_type': 'state',
                                'editions': {'Watts & Serg.': (datetime.date(1841, 1, 1),
                                                               datetime.date(1845, 12, 31))},
                                'mlz_jurisdiction': 'us;pa',
                                'name': 'Pennsylvania State Reports, Watts & Sergeant',
                                'variations': {'W.& S.': 'Watts & Serg.',
                                               'Watts & S.': 'Watts & Serg.'}}],
             'Wend.': [{'cite_type': 'state',
                        'editions': {'Wend.': (datetime.date(1828, 1, 1),
                                               datetime.date(1841, 12, 31))},
                        'mlz_jurisdiction': 'us;ny',
                        'name': "Wendell's Reports",
                        'variations': {'W.': 'Wend.',
                                       'Wend.(N.Y.)': 'Wend.',
                                       'Wendell': 'Wend.'}}],
             'Whart.': [{'cite_type': 'state',
                         'editions': {'Whart.': (datetime.date(1835, 1, 1),
                                                 datetime.date(1841, 12, 31))},
                         'mlz_jurisdiction': 'us;pa',
                         'name': 'Pennsylvania State Reports, Wharton',
                         'variations': {'Wh.': 'Whart.',
                                        'Whar.': 'Whart.',
                                        'Whart.Pa.': 'Whart.',
                                        'Wharton': 'Whart.'}}],
             'Wheat.': [{'cite_type': 'fed',
                         'editions': {'Wheat': (datetime.date(1816, 1, 1),
                                                datetime.date(1827, 12, 31))},
                         'mlz_jurisdiction': 'us',
                         'name': "Wheaton's Supreme Court Reports",
                         'variations': {'U.S.(Wheat.)': 'Wheat.', 'Wheaton': 'Wheat.'}}],
             'White & W.': [{'cite_type': 'state',
                             'editions': {'White & W.': (datetime.date(1876, 1, 1),
                                                         datetime.date(1883, 12, 31))},
                             'mlz_jurisdiction': 'us;tx',
                             'name': 'Condensed Reports of Decisions in Civil Causes in the Court of Appeals of Texas (White & Wilson)',
                             'variations': {'Tex.A.Civ.': 'White & W.',
                                            'Tex.A.Civ.Cas.': 'White & W.',
                                            'Tex.App.': 'White & W.',
                                            'Tex.C.C.': 'White & W.',
                                            'Tex.Civ.Cas.': 'White & W.',
                                            'Tex.Ct.App.Dec.Civ.': 'White & W.',
                                            'W.& W.': 'White & W.',
                                            'White & W.(Tex.)': 'White & W.',
                                            'White & W.Civ.Cas.Ct.App.': 'White & W.',
                                            'Wi.& Will.': 'White & W.'}}],
             'Will.': [{'cite_type': 'state',
                        'editions': {'Will.': (datetime.date(1804, 1, 1),
                                               datetime.date(1805, 12, 31))},
                        'mlz_jurisdiction': 'us;ma',
                        'name': 'Massachusetts Reports, Williams',
                        'variations': {'Mass.(Will.)': 'Will.',
                                       'Will.Mass.': 'Will.',
                                       'Williams': 'Will.'}}],
             'Wilson': [{'cite_type': 'state',
                         'editions': {'Wilson': (datetime.date(1883, 1, 1),
                                                 datetime.date(1892, 12, 31))},
                         'mlz_jurisdiction': 'us;tx',
                         'name': 'Condensed Reports of Decisions in Civil Causes in the Court of Appeals of Texas (Wilson)',
                         'variations': {}}],
             'Win.': [{'cite_type': 'state',
                       'editions': {'Win.': (datetime.date(1863, 1, 1),
                                             datetime.date(1864, 12, 31))},
                       'mlz_jurisdiction': 'us;nc',
                       'name': 'North Carolina Reports, Winston',
                       'variations': {}}],
             'Wis.': [{'cite_type': 'state',
                       'editions': {'Wis.': (datetime.date(1853, 1, 1),
                                             datetime.date.today()),
                                    'Wis. 2d': (datetime.date(1853, 1, 1),
                                                datetime.date.today())},
                       'mlz_jurisdiction': 'us;wi',
                       'name': 'Wisconsin Reports',
                       'variations': {'W.': 'Wis.',
                                      'W.2d': 'Wis. 2d',
                                      'W.R.': 'Wis.',
                                      'Wis.2d': 'Wis. 2d'}}],
             'Wyo.': [{'cite_type': 'state',
                       'editions': {'Wyo.': (datetime.date(1870, 1, 1),
                                             datetime.date(1959, 12, 31))},
                       'mlz_jurisdiction': 'us;wy',
                       'name': 'Wyoming Reports',
                       'variations': {'W.': 'Wyo.', 'Wy.': 'Wyo.'}}],
             'Yates Sel. Cas.': [{'cite_type': 'state',
                                  'editions': {'Yates Sel. Cas.': (datetime.date(1809, 1, 1),
                                                                   datetime.date(1809, 12, 31))},
                                  'mlz_jurisdiction': 'us;ny',
                                  'name': "Yates' Select Cases",
                                  'variations': {'Yates': 'Yates Sel. Cas.',
                                                 'Yates Sel.Cas.(N.Y.)': 'Yates Sel. Cas.'}}],
             'Yeates': [{'cite_type': 'state',
                         'editions': {'Yeates': (datetime.date(1791, 1, 1),
                                                 datetime.date(1808, 12, 31))},
                         'mlz_jurisdiction': 'us;pa',
                         'name': 'Pennsylvania State Reports, Yeates',
                         'variations': {'Y.': 'Yeates', 'Yea.': 'Yeates'}}],
             'Yer.': [{'cite_type': 'state',
                       'editions': {'Yer.': (datetime.date(1828, 1, 1),
                                             datetime.date(1837, 12, 31))},
                       'mlz_jurisdiction': 'us;tn',
                       'name': 'Tennessee Reports, Yerger',
                       'variations': {'Tenn.(Yer.)': 'Yer.',
                                      'Yerg.': 'Yer.',
                                      'Yerg.(Tenn.)': 'Yer.'}}]}
